@@ -9,11 +9,12 @@ import math as maths
 import numpy as np
 
 import resqpy.crs as rqc
+import resqpy.derived_model
 import resqpy.model as rq
 import resqpy.olio.xml_et as rqet
 
-from resqpy.derived_model._common import _displacement_properties, _prepare_simple_inheritance, _write_grid, _establish_model_and_source_grid
-from resqpy.derived_model._copy_grid import copy_grid
+import resqpy.derived_model._common as rqdm_c
+import resqpy.derived_model._copy_grid as rqdm_cg
 
 
 def local_depth_adjustment(epc_file,
@@ -79,12 +80,12 @@ def local_depth_adjustment(epc_file,
         (new_epc_file == epc_file) or
         (os.path.exists(new_epc_file) and os.path.exists(epc_file) and os.path.samefile(new_epc_file, epc_file))):
         new_epc_file = None
-    model, source_grid = _establish_model_and_source_grid(epc_file, source_grid)
+    model, source_grid = rqdm_c._establish_model_and_source_grid(epc_file, source_grid)
     assert source_grid.grid_representation == 'IjkGrid'
     assert model is not None
 
     # take a copy of the grid
-    grid = copy_grid(source_grid, model, copy_crs = True)
+    grid = rqdm_cg.copy_grid(source_grid, model, copy_crs = True)
 
     # if not use_local_coords, convert centre_x & y into local_coords
     if grid.crs is None:
@@ -156,12 +157,12 @@ def local_depth_adjustment(epc_file,
     # build cell displacement property array(s)
     if store_displacement:
         log.debug('generating cell displacement property arrays')
-        displacement_collection = _displacement_properties(grid, source_grid)
+        displacement_collection = rqdm_c._displacement_properties(grid, source_grid)
     else:
         displacement_collection = None
 
-    collection = _prepare_simple_inheritance(grid, source_grid, inherit_properties, inherit_realization,
-                                             inherit_all_realizations)
+    collection = rqdm_c._prepare_simple_inheritance(grid, source_grid, inherit_properties, inherit_realization,
+                                                    inherit_all_realizations)
     if collection is None:
         collection = displacement_collection
     elif displacement_collection is not None:
@@ -174,16 +175,20 @@ def local_depth_adjustment(epc_file,
     # write model
     model.h5_release()
     if new_epc_file:
-        _write_grid(new_epc_file, grid, property_collection = collection, grid_title = new_grid_title, mode = 'w')
+        rqdm_c._write_grid(new_epc_file,
+                           grid,
+                           property_collection = collection,
+                           grid_title = new_grid_title,
+                           mode = 'w')
     else:
         ext_uuid, _ = model.h5_uuid_and_path_for_node(rqet.find_nested_tags(source_grid.root, ['Geometry', 'Points']),
                                                       'Coordinates')
-        _write_grid(epc_file,
-                    grid,
-                    ext_uuid = ext_uuid,
-                    property_collection = collection,
-                    grid_title = new_grid_title,
-                    mode = 'a')
+        rqdm_c._write_grid(epc_file,
+                           grid,
+                           ext_uuid = ext_uuid,
+                           property_collection = collection,
+                           grid_title = new_grid_title,
+                           mode = 'a')
 
     return grid
 
