@@ -293,7 +293,7 @@ def set_geometry_is_defined(grid,
 
     assert not np.all(nan_mask), 'grid does not have any geometry defined'
 
-    points[np.where(np.repeat(np.expand_dims(nan_mask, axis = nan_mask.ndim), 3, axis = -1))] = np.NaN
+    points[np.where(np.repeat(np.expand_dims(nan_mask, axis = nan_mask.ndim), 3, axis = -1))] = np.nan
 
     surround_z = grid.xyz_box(lazy = False)[1 if grid.z_inc_down() else 0, 2]
 
@@ -335,7 +335,7 @@ def set_geometry_is_defined(grid,
     if nullify_partial_pillars:
         partial_pillar_mask = np.logical_and(pillar_defined_mask, np.any(nan_mask, axis = 0).flatten())
         if np.any(partial_pillar_mask):
-            points.reshape((grid.nk_plus_k_gaps + 1, -1, 3))[:, partial_pillar_mask, :] = np.NaN
+            points.reshape((grid.nk_plus_k_gaps + 1, -1, 3))[:, partial_pillar_mask, :] = np.nan
             grid.geometry_defined_for_all_pillars_cached = False
             cells_update_needed = True
     elif complete_partial_pillars:
@@ -348,6 +348,7 @@ def set_geometry_is_defined(grid,
 
     if complete_all:
         cells_update_needed = __complete_all_pillars(cells_update_needed, grid, points, surround_z)
+        cells_update_needed = True
 
     if cells_update_needed:
         # note: each pillar is either fully defined or fully undefined at this point
@@ -387,7 +388,10 @@ def __complete_all_pillars(cells_update_needed, grid, points, surround_z):
     if hasattr(grid, 'array_pillar_geometry_is_defined'):
         del grid.array_pillar_geometry_is_defined
     cells_update_needed = False
-    assert not np.any(np.isnan(points))
+    nan_mask = np.isnan(points)
+    if np.any(nan_mask):
+        log.warning('remaining NaNs after filling missing pillar geometry will be set to zero (dangerous)')
+        points[nan_mask] = 0.0
     grid.geometry_defined_for_all_cells_cached = True
     if hasattr(grid, 'array_cell_geometry_is_defined'):
         del grid.array_cell_geometry_is_defined
@@ -412,7 +416,7 @@ def __handle_areal_dots(areal_dots, grid, nan_mask):
         primaries = (grid.nj + 1) * (grid.ni + 1)
         nan_mask[:, :primaries] = np.logical_or(nan_mask[:, :primaries], dot_mask.reshape((-1, primaries)))
     else:
-        nan_mask = np.where(dot_mask, np.NaN, nan_mask)
+        nan_mask = np.where(dot_mask, np.nan, nan_mask)
     return nan_mask
 
 
@@ -585,7 +589,7 @@ def __fill_holes(grid, holes_mask):
 def __fill_surround(grid, surround_mask):
     # note: only fills x,y; based on bottom layer of points; assumes surround mask is a regularly shaped frame of columns
     log.debug(f'filling {np.count_nonzero(surround_mask)} pillars for surround')
-    points = grid.points_ref(masked = False)
+    points = grid.points_ref(masked = False).reshape((grid.nk_plus_k_gaps + 1, -1, 3))
     points_view = points[-1, :, :2].reshape((-1, 2))[:(grid.nj + 1) * (grid.ni + 1), :].reshape(
         (grid.nj + 1, grid.ni + 1, 2))
     modified = False
