@@ -20,11 +20,13 @@ __all__ = [
     "find_faces_to_represent_surface_staffa",
     "find_faces_to_represent_surface_regular",
     "find_faces_to_represent_surface_regular_optimised",
+    "find_faces_to_represent_surface_regular_dense_optimised",
     "find_faces_to_represent_surface",
     "bisector_from_faces",
     "column_bisector_from_faces",
     "shadow_from_faces",
     "get_boundary",
+    "get_boundary_dict",
     "_where_true",
     "_first_true",
     "intersect_numba",
@@ -56,11 +58,13 @@ from ._find_faces import (
     find_faces_to_represent_surface_staffa,
     find_faces_to_represent_surface_regular,
     find_faces_to_represent_surface_regular_optimised,
+    find_faces_to_represent_surface_regular_dense_optimised,
     find_faces_to_represent_surface,
     bisector_from_faces,
     column_bisector_from_faces,
     shadow_from_faces,
     get_boundary,
+    get_boundary_dict,
     _where_true,
     _first_true,
     intersect_numba,
