@@ -553,6 +553,15 @@ def _citation_title_for_part(model, part):  # duplicate functionality to title_f
     return title
 
 
+def _source_for_part(model, part):
+    """Returns the source string from the part's extra metadata, if present, else None."""
+
+    part_extra = rqet.load_metadata_from_xml(_root_for_part(model, part))
+    if not part_extra:
+        return None
+    return part_extra.get('source')
+
+
 def _root_for_time_series(model, uuid = None):
     """Return root for time series part."""
 
@@ -721,11 +730,12 @@ def _filtered_by_title(model, parts_list, title, title_mode, title_case_sensitiv
     assert title_mode in [
         'is', 'starts', 'ends', 'contains', 'is not', 'does not start', 'does not end', 'does not contain'
     ]
+    title = title.strip()
     if not title_case_sensitive:
         title = title.upper()
     filtered_list = []
     for part in parts_list:
-        part_title = _citation_title_for_part(model, part)
+        part_title = _citation_title_for_part(model, part).strip()
         if not title_case_sensitive:
             part_title = part_title.upper()
         if title_mode == 'is':
