@@ -200,8 +200,8 @@ def _load_epc(model, epc_file, full_load = True, epc_subdir = None, copy_from =
 def _add_uuid_soft_relations(model, uuid_int, part):
     if "EpcExternalPart" in part:
         return
-    value = model.rels_forest.get(rqet.rels_part_name_for_part(part))
-    if value is not None:
+    rels_part = rqet.rels_part_name_for_part(part)
+    if rels_part in model.rels_forest:
         rels_root = m_c._root_for_part(model, rqet.rels_part_name_for_part(part), is_rels = True)
         if rels_root is not None:
             for relation_node in rels_root:
@@ -214,9 +214,10 @@ def _add_uuid_soft_relations(model, uuid_int, part):
                 if relation_uuid_str is None:
                     return  # probably HDF5 external resource
                 relation_uuid_int = _hex_to_int(relation_uuid_str)
-                value = model.uuid_rels_dict.get(uuid_int)
-                if value is not None and relation_uuid_int not in value[0] and relation_uuid_int not in value[1]:
-                    value[2].add(relation_uuid_int)
+                rels_sets = model.uuid_rels_dict.get(uuid_int)
+                if rels_sets is not None and relation_uuid_int not in rels_sets[
+                        0] and relation_uuid_int not in rels_sets[1]:
+                    rels_sets[2].add(relation_uuid_int)
 
 
 def _add_uuid_relations(model, uuid_int, part):
@@ -652,14 +653,19 @@ def _copy_referenced_parts(model, other_model, realization, consolidate, force,
     relatives = other_model.uuid_rels_dict.get(uuid.int)
     if relatives is None:  # todo: have a think about whether this is indicating a problem
         return
+    # log.debug(f'copying {len(relatives[0])} referenced parts for uuid: {uuid} of type: {model.type_of_uuid(uuid)}')
     for ref_uuid_int in relatives[0]:  # using dict in other model instead of duplicated xml
         if ref_uuid_int in model.uuid_part_dict:
+            m_x._create_reciprocal_relationship(model, root_node, 'sourceObject',
+                                                m_c._root_for_uuid(model, ref_uuid_int), 'destinationObject')
             continue
         if not force:
             referred_part = m_c._part_for_uuid(other_model, bu.uuid_from_int(ref_uuid_int))
             if m_c._type_of_part(other_model, referred_part) == 'obj_EpcExternalPartReference':
                 continue
             if referred_part in m_c._list_of_parts(model):
+                m_x._create_reciprocal_relationship(model, root_node, 'sourceObject',
+                                                    m_c._root_for_part(model, referred_part), 'destinationObject')
                 continue
             resident_part = _copy_part_from_other_model(model,
                                                         other_model,
@@ -714,9 +720,6 @@ def _copy_relationships_for_present_targets(model, other_model, consolidate, for
                         continue
                 else:
                     continue
-            if not force and resident_related_part in m_c._parts_list_filtered_by_related_uuid(
-                    model, m_c._list_of_parts(model), resident_uuid):
-                continue
             related_node = m_c._root_for_part(model, resident_related_part)
             assert related_node is not None
 
