@@ -420,22 +420,39 @@ def _create_supporting_representation(model,
 
 
 def _create_source(source, root = None):
-    """Create an extra meta data node holding information on the source of the data, optionally add to root."""
+    """Create an extra meta data node holding information on the source of the data, optionally add to root.
 
-    emd_node = rqet.Element(ns['resqml2'] + 'ExtraMetadata')
-    emd_node.set(ns['xsi'] + 'type', ns['resqml2'] + 'NameValuePair')
-    emd_node.text = rqet.null_xml_text
-
-    name_node = rqet.SubElement(emd_node, ns['resqml2'] + 'Name')
-    name_node.set(ns['xsi'] + 'type', ns['xsd'] + 'string')
-    name_node.text = 'source'
-
-    value_node = rqet.SubElement(emd_node, ns['resqml2'] + 'Value')
-    value_node.set(ns['xsi'] + 'type', ns['xsd'] + 'string')
-    value_node.text = source
+    note:
+        if the root already contains a 'source' extra metadata item, its text field is updated and the
+        existing extra metadata xml node is returned
+    """
 
+    emd_node = None
     if root is not None:
-        root.append(emd_node)
+        emd_node = rqet.find_metadata_item_node_in_xml(root, 'source')
+
+    if emd_node is None:
+
+        emd_node = rqet.Element(ns['resqml2'] + 'ExtraMetadata')
+        emd_node.set(ns['xsi'] + 'type', ns['resqml2'] + 'NameValuePair')
+        emd_node.text = rqet.null_xml_text
+
+        name_node = rqet.SubElement(emd_node, ns['resqml2'] + 'Name')
+        name_node.set(ns['xsi'] + 'type', ns['xsd'] + 'string')
+        name_node.text = 'source'
+
+        value_node = rqet.SubElement(emd_node, ns['resqml2'] + 'Value')
+        value_node.set(ns['xsi'] + 'type', ns['xsd'] + 'string')
+        value_node.text = str(source)
+
+        if root is not None:
+            root.append(emd_node)
+
+    else:
+
+        value_node = rqet.find_tag(emd_node, 'Value')
+        assert value_node is not None
+        value_node.text = str(source)
 
     return emd_node
 
@@ -457,7 +474,9 @@ def _create_patch(model,
         assert ext_uuid is not None
     else:
         assert const_count is not None and const_count > 0
-        if hdf5_type.endswith('Hdf5Array'):
+        if isinstance(const_value, bool):
+            hdf5_type = 'BooleanConstantArray'  # not actually stored in hdf5
+        elif hdf5_type.endswith('Hdf5Array'):
             hdf5_type = hdf5_type[:-9] + 'ConstantArray'
 
     lxt = str(xsd_type).lower()
@@ -488,6 +507,7 @@ def _create_patch(model,
     outer_values_node.text = rqet.null_xml_text
 
     if discrete and const_value is None:
+
         if null_value is None:
             if str(xsd_type).startswith('u'):
                 null_value = 4294967295  # 2^32 - 1, used as default even for 64 bit data!
@@ -507,6 +527,11 @@ def _create_patch(model,
 
     else:
 
+        # TODO: handle bool const_value as special case
+        if isinstance(const_value, bool):
+            const_value = str(const_value).lower()
+            xsd_type = 'boolean'
+
         const_value_node = rqet.SubElement(outer_values_node, ns['resqml2'] + 'Value')
         const_value_node.set(ns['xsi'] + 'type', ns['xsd'] + xsd_type)
         const_value_node.text = str(const_value)
