@@ -29,6 +29,7 @@ def find_faces_to_represent_surface_regular_wrapper(
         name: str,
         title: Optional[str] = None,
         agitate: bool = False,
+        random_agitation: bool = False,
         feature_type: str = 'fault',
         trimmed: bool = False,
         is_curtain = False,
@@ -41,7 +42,8 @@ def find_faces_to_represent_surface_regular_wrapper(
         extra_metadata = None,
         return_properties: Optional[List[str]] = None,
         raw_bisector: bool = False,
-        use_pack: bool = False) -> Tuple[int, bool, str, List[Union[UUID, str]]]:
+        use_pack: bool = False,
+        flange_radius = None) -> Tuple[int, bool, str, List[Union[UUID, str]]]:
     """Multiprocessing wrapper function of find_faces_to_represent_surface_regular_optimised.
 
     arguments:
@@ -55,14 +57,22 @@ def find_faces_to_represent_surface_regular_wrapper(
         surface_uuid (UUID or str): UUID (universally unique identifier) of the surface (or point set) object.
         name (str): the feature name to use in the grid connection set.
         title (str): the citation title to use for the grid connection set; defaults to name
-        agitate (bool): if True, the points of the surface are perturbed by a small random
-           offset, which can help if the surface has been built from a regular mesh with a periodic resonance
+        agitate (bool): if True, the points of the surface are perturbed by a small offset,
+           which can help if the surface has been built from a regular mesh with a periodic resonance
            with the grid
+        random_agitation (bool, default False): if True, the agitation is by a small random distance; if False,
+           a constant positive shift of 5.0e-6 is applied to x, y & z values; ignored if agitate is False
         feature_type (str, default 'fault'): one of 'fault', 'horizon', or 'geobody boundary'
         trimmed (bool, default True): if True the surface has already been trimmed
         is_curtain (bool, default False): if True, only the top layer is intersected with the surface and bisector
            is generated as a column property if requested
         extend_fault_representation (bool, default False): if True, the representation is extended with a flange
+        flange_inner_ring (bool, default False): if True, an inner ring of points, with double flange point counr,
+           is created at a radius just outside that of the furthest flung original point; this improves
+           triangulation of the extended point set when the original has a non-convex hull
+        saucer_parameter (float, optional): if present, and extend_with_flange is True, then a parameter
+           controlling the shift of flange points in a perpendicular direction away from the fault plane;
+           see notes for how this parameter is interpreted
         retriangulate (bool, default False): if True, a retriangulation is performed even if not needed otherwise
         related_uuid (uuid, optional): if present, the uuid of an object to be softly related to the gcs (and to
            grid bisector and/or shadow property if requested)
@@ -84,6 +94,8 @@ def find_faces_to_represent_surface_regular_wrapper(
            form without assessing which side is shallower (True values indicate same side as origin cell)
         use_pack (bool, default False): if True, boolean properties will be stored in numpy packed format,
            which will only be readable by resqpy based applications
+        flange_radius (float, optional): the radial distance to use for outer flange extension points; if None,
+           a large value will be calculated from the grid size; units are xy units of grid crs
 
     returns:
         Tuple containing:
@@ -95,7 +107,16 @@ def find_faces_to_represent_surface_regular_wrapper(
     notes:
         Use this function as argument to the multiprocessing function; it will create a new model that is saved
         in a temporary epc file and returns the required values, which are used in the multiprocessing function to
-        recombine all the objects into a single epc file
+        recombine all the objects into a single epc file;
+        the saucer_parameter is interpreted in one of two ways: (1) +ve fractoinal values between zero and one
+        are the fractional distance from the centre of the points to its rim at which to sample the surface for
+        extrapolation and thereby modify the recumbent z of flange points; 0 will usually give shallower and
+        smoother saucer; larger values (must be less than one) will lead to stronger and more erratic saucer
+        shape in flange; (2) other values between -90.0 and 90.0 are interpreted as an angle to apply out of
+        the plane of the original points, to give a simple (and less computationally demanding) saucer shape;
+        +ve angles result in the shift being in the direction of the -ve z hemisphere; -ve angles result in
+        the shift being in the +ve z hemisphere; in either case the direction of the shift is perpendicular
+        to the average plane of the original points
     """
     tmp_dir = Path(parent_tmp_dir) / f"{uuid.uuid4()}"
     tmp_dir.mkdir(parents = True, exist_ok = True)
@@ -120,7 +141,8 @@ def find_faces_to_represent_surface_regular_wrapper(
             log.warning(f'grid cell length property {prop_title} NOT found')
     grid = grr.RegularGrid(parent_model = model, uuid = grid_uuid)
     assert grid.is_aligned
-    flange_radius = 5.0 * np.sum(np.array(grid.extent_kji, dtype = float) * np.array(grid.aligned_dxyz()))
+    if flange_radius is None:
+        flange_radius = 5.0 * np.sum(np.array(grid.extent_kji, dtype = float) * np.array(grid.aligned_dxyz()))
     s_model = rq.Model(surface_epc, quiet = True)
     model.copy_uuid_from_other_model(s_model, uuid = str(surface_uuid))
     repr_type = model.type_of_part(model.part(uuid = surface_uuid), strip_obj = True)
@@ -157,6 +179,7 @@ def find_faces_to_represent_surface_regular_wrapper(
                                               extend_with_flange = extend_fault_representation,
                                               flange_inner_ring = flange_inner_ring,
                                               saucer_parameter = saucer_parameter,
+                                              flange_radial_factor = 1.2,
                                               flange_radial_distance = flange_radius,
                                               make_clockwise = False)
         extended = extend_fault_representation
@@ -212,7 +235,8 @@ def find_faces_to_represent_surface_regular_wrapper(
                                            property_kind = 'flange bool',
                                            find_local_property_kind = True,
                                            indexable_element = 'faces',
-                                           discrete = True)
+                                           discrete = True,
+                                           dtype = np.uint8)
         uuid_list.append(flange_p.uuid)
     uuid_list.append(surface_uuid)
 
@@ -221,6 +245,7 @@ def find_faces_to_represent_surface_regular_wrapper(
                                                                      name,
                                                                      title,
                                                                      agitate,
+                                                                     random_agitation,
                                                                      feature_type,
                                                                      is_curtain,
                                                                      progress_fn,
