@@ -1,4 +1,4 @@
-"""Simple functions relating to cartesian grid boxes
+"""Simple functions relating to cartesian grid boxes.
 
 A box is a logical cuboid subset of the cells of a cartesian grid.
 A box is defined by a small numpy array: [[min_k, min_j, min_i], [max_k, max_j, max_i]].
@@ -7,8 +7,6 @@ The ordering of the i,j & k indices might be reversed - identifier names then ha
 The indices can be in simulator convention, starting at 1, or python convention, starting at 0, indicated by suffix of 0 or 1
 """
 
-version = '13th July 2021'
-
 import logging
 
 log = logging.getLogger(__name__)
