@@ -1,7 +1,5 @@
 """fine_coarse.py: Module providing support for grid refinement and coarsening."""
 
-version = '20th October 2021'
-
 # Nexus is a registered trademark of the Halliburton Company
 
 # todo: cater for parallel to top & parallel to base style refinement proportions in k
@@ -248,9 +246,10 @@ class FineCoarse:
         assert isinstance(vector, np.ndarray) and vector.ndim == 1
         assert str(vector.dtype).startswith('int')
         assert len(vector) == self.coarse_extent_kji[axis],  \
-               'length of vector of refinement ratios does not match coarse extent'
+               f'length of vector {len(vector)} of refinement ratios ' +  \
+               f'does not match coarse extent {self.coarse_extent_kji[axis]}'
         assert np.sum(vector) == self.fine_extent_kji[axis],  \
-               'sum of refinement ratios in vector does not match fine extent'
+               f'sum of refinement ratios {np.sum(vector)} in vector does not match fine extent'
         minimum = np.min(vector)
         assert minimum > 0
         if minimum == np.max(vector):
@@ -267,7 +266,7 @@ class FineCoarse:
         self.equal_proportions[axis] = True
         self.vector_proportions[axis] = None
 
-    def set_all_proprtions_equal(self):
+    def set_all_proportions_equal(self):
         """Sets proportions equal in all 3 axes."""
 
         for axis in range(3):
