@@ -115,7 +115,7 @@ def _dt_simple(po, plot_fn = None, progress_fn = None, container_size_factor = N
     if n_p < 3:
         return None, None  # not enough points
     elif n_p == 3:
-        return np.array([0, 1, 2], dtype = int).reshape((1, 3)), np.array([0, 1, 2], dtype = int)
+        return np.array([0, 1, 2], dtype = np.int32).reshape((1, 3)), np.array([0, 1, 2], dtype = np.int32)
 
     if progress_fn is not None:
         progress_fn(0.0)
@@ -133,19 +133,20 @@ def _dt_simple(po, plot_fn = None, progress_fn = None, container_size_factor = N
     p[-1] = (min_xy[0] + 0.5 * csf * dxy[0], max_xy[1] + 0.8 * csf * dxy[1])
 
     # triangle vertex indices
-    t = np.empty((2 * n_p + 2, 3), dtype = int)  # empty space for triangle vertex indices
+    t_type = np.int32 if n_p < 2_147_483_648 else np.int64
+    t = np.empty((2 * n_p + 2, 3), dtype = t_type)  # empty space for triangle vertex indices
     t[0] = (n_p, n_p + 1, n_p + 2)  # initial set of one containing triangle
     nt = 1  # number of triangles so far populated
 
     # edges: list of indices of triangles and edge within triangle; -1 indicates no triangle using edge
-    e = np.full((3 * n_p + 6, 2, 2), fill_value = -1, dtype = int)
+    e = np.full((3 * n_p + 6, 2, 2), fill_value = -1, dtype = t_type)
     e[:3, 0, 0] = 0
     for edge in range(3):
         e[edge, 0, 1] = edge
     ne = 3  # number of edges so far in use
 
     # edge indices (in e) for each triangle, first axis indexed in sync with t
-    te = np.empty((2 * n_p + 2, 3), dtype = int)  # empty space for triangle edge indices
+    te = np.empty((2 * n_p + 2, 3), dtype = t_type)  # empty space for triangle edge indices
     te[0] = (0, 1, 2)
 
     # mask tracking which edges have been flipped
@@ -501,7 +502,7 @@ def voronoi(p, t, b, aoi: rql.Polyline):
         return trimmed_ci
 
     def __veroni_cells(aoi_count, aoi_intersect_segments, b, c, c_count, ca_count, cah_count, caho_count, cahon_count,
-                       hull_count, out_pair_intersect_segments, p, t, tc_outwith_aoi):
+                       hull_count, out_pair_intersect_segments, p, t, tc_outwith_aoi, t_type):
         # list of voronoi cells (each a numpy list of node indices into c extended with aoi points etc)
         v = []
         # for each seed point build the voronoi cell
@@ -550,7 +551,7 @@ def voronoi(p, t, b, aoi: rql.Polyline):
                                                   ci_for_p, out_pair_intersect_segments)
 
             #  remove circumcircle centres that are outwith area of interest
-            ci_for_p = np.array([ti for ti in ci_for_p if ti >= c_count or ti not in tc_outwith_aoi], dtype = int)
+            ci_for_p = np.array([ti for ti in ci_for_p if ti >= c_count or ti not in tc_outwith_aoi], dtype = t_type)
 
             # find azimuths of vectors from seed point to circumcircle centres and aoi boundary points
             azi = [vec.azimuth(centre - p[p_i, :2]) for centre in c[ci_for_p, :2]]
@@ -612,11 +613,12 @@ def voronoi(p, t, b, aoi: rql.Polyline):
     caho_count = cah_count + 2 * o_count
     cahon_count = caho_count + hull_count
     assert cahon_count + hull_count == len(c)
+    t_type = np.int32 if len(c) < 2_147_483_648 else np.int64
 
     #  compute intersection points between hull edge normals and aoi polyline
     # also extended virtual centres for hull edges
     extension_scaling = 1000.0 * np.sum((np.max(aoi.coordinates, axis = 0) - np.min(aoi.coordinates, axis = 0))[:2])
-    aoi_intersect_segments = np.empty((hull_count,), dtype = int)
+    aoi_intersect_segments = np.empty((hull_count,), dtype = t_type)
     for ei in range(hull_count):
         # use segment midpoint and normal methods of hull to project out
         m = hull.segment_midpoint(ei)[:2]  # midpoint
@@ -638,8 +640,8 @@ def voronoi(p, t, b, aoi: rql.Polyline):
         c[cahon_count + ei] = hull.coordinates[ei, :2] + extension_scaling * vector
 
     # where cicrumcircle centres are outwith aoi, compute intersections of normals of wing edges with aoi
-    out_pair_intersect_segments = np.empty((o_count, 2), dtype = int)
-    wing_hull_segments = np.empty((o_count, 2), dtype = int)
+    out_pair_intersect_segments = np.empty((o_count, 2), dtype = t_type)
+    wing_hull_segments = np.empty((o_count, 2), dtype = t_type)
     for oi, ti in enumerate(tc_outwith_aoi):
         tpi = __shorter_sides_p_i(p[t[ti]])
         for wing in range(2):
@@ -658,7 +660,7 @@ def voronoi(p, t, b, aoi: rql.Polyline):
             tpi = (tpi + 1) % 3
 
     v = __veroni_cells(aoi_count, aoi_intersect_segments, b, c, c_count, ca_count, cah_count, caho_count, cahon_count,
-                       hull_count, out_pair_intersect_segments, p, t, tc_outwith_aoi)
+                       hull_count, out_pair_intersect_segments, p, t, tc_outwith_aoi, t_type)
 
     return c[:caho_count], v
 
@@ -703,7 +705,8 @@ def triangulated_polygons(p, v, centres = None):
         points[len(p):] = centres
 
     t_count = sum([len(x) for x in v])
-    triangles = np.empty((t_count, 3), dtype = int)
+    t_type = np.int32 if len(points) < 2_147_483_648 else np.int64
+    triangles = np.empty((t_count, 3), dtype = t_type)
     t_index = 0
 
     for cell, poly_vertices in enumerate(v):
@@ -711,7 +714,7 @@ def triangulated_polygons(p, v, centres = None):
         centre_i = len(p) + cell
         if centres is None:
             polygon = rql.Polyline(model,
-                                   set_coord = p[np.array(poly_vertices, dtype = int)],
+                                   set_coord = p[np.array(poly_vertices, dtype = t_type)],
                                    is_closed = True,
                                    set_crs = crs.uuid,
                                    title = 'v cell')
@@ -726,7 +729,7 @@ def triangulated_polygons(p, v, centres = None):
     return points, triangles
 
 
-def reorient(points, rough = True, max_dip = None, use_linalg = False):
+def reorient(points, rough = True, max_dip = None, use_linalg = True, sample = 500):
     """Returns a reoriented copy of a set of points, such that z axis is approximate normal to average plane of points.
 
     arguments:
@@ -735,12 +738,13 @@ def reorient(points, rough = True, max_dip = None, use_linalg = False):
           if False, that reduces to around 2.5 degrees of the optimum; iugnored if use_linalg is True
        max_dip (float, optional): if present, the reorientation of perspective off vertical is
           limited to this angle in degrees
-       use_linalg (bool, default False): if True, the numpy linear algebra svd function is used and rough is ignored
+       use_linalg (bool, default True): if True, the numpy linear algebra svd function is used and rough is ignored
+       sample (int, default 500): downsample points to this number for the purposes of determining normal vector
 
     returns:
        numpy float array of the same shape as points, numpy xyz vector, numpy 3x3 matrix;
        the array being a copy of points rotated in 3D space to minimise the z range;
-       the vector is a normal vector to the original points;
+       the vector is a normal vector to the original points, in +ve z hemisphere;
        the matrix is rotation matrix used to transform the original points to the reoriented points
 
     notes:
@@ -748,7 +752,9 @@ def reorient(points, rough = True, max_dip = None, use_linalg = False):
        implicit xy & z units for points are assumed to be the same;
        the function may typically be called prior to the Delauney triangulation, which uses an xy projection to
        determine the triangulation;
-       the numpy linear algebra option seems to be memory intensive, not recommended
+       the numpy linear algebra option seems to be memory intensive, not recommended;
+       downsampling will occur (for normal vector determination) when the number of points exceeds double that
+       given in the sample argument; set sample to None to use all points for normal vector determination
     """
 
     def best_angles(points, mid_x, mid_y, steps, d_theta):
@@ -780,8 +786,16 @@ def reorient(points, rough = True, max_dip = None, use_linalg = False):
 
     assert points.ndim >= 2 and points.shape[-1] == 3
 
+    if sample is not None and len(points) > 2 * sample:
+        step = len(points) // sample
+        p = points[::step, :]
+    else:
+        p = points
+
     if use_linalg:
-        normal_vector = linalg_normal_vector(points)
+        normal_vector = linalg_normal_vector(p)
+        if normal_vector[2] < 0.0:
+            normal_vector = -normal_vector
         incl = vec.inclination(normal_vector)
         if incl == 0.0:
             rotation_m = vec.no_rotation_matrix()
@@ -790,14 +804,14 @@ def reorient(points, rough = True, max_dip = None, use_linalg = False):
             rotation_m = vec.tilt_3d_matrix(azi, incl)
     else:
         # coarse iteration trying a few different angles
-        best_x_rotation, best_y_rotation = best_angles(points, 0.0, 0.0, 7, 30.0)
+        best_x_rotation, best_y_rotation = best_angles(p, 0.0, 0.0, 7, 30.0)
 
         # finer iteration searching around the best coarse rotation
-        best_x_rotation, best_y_rotation = best_angles(points, best_x_rotation, best_y_rotation, 5, 10.0)
+        best_x_rotation, best_y_rotation = best_angles(p, best_x_rotation, best_y_rotation, 5, 10.0)
 
         if not rough:
             # finer iteration searching around the best coarse rotation
-            best_x_rotation, best_y_rotation = best_angles(points, best_x_rotation, best_y_rotation, 7, 2.5)
+            best_x_rotation, best_y_rotation = best_angles(p, best_x_rotation, best_y_rotation, 7, 2.5)
 
         rotation_m = vec.rotation_3d_matrix((best_x_rotation, 0.0, best_y_rotation))
 
@@ -809,7 +823,7 @@ def reorient(points, rough = True, max_dip = None, use_linalg = False):
         if incl > max_dip:
             azi = vec.azimuth(v)
             rotation_m = vec.tilt_3d_matrix(azi, max_dip)  # TODO: check whether any reverse direction errors here
-        normal_vector = vec.rotate_vector(rotation_m.T, np.array((0.0, 0.0, 1.0)))
+            normal_vector = vec.rotate_vector(rotation_m.T, np.array((0.0, 0.0, 1.0)))
 
     p = points.copy()
 
@@ -831,7 +845,12 @@ def make_all_clockwise_xy(t, p):
     return t
 
 
-def surrounding_xy_ring(p, count = 12, radial_factor = 10.0, radial_distance = None, inner_ring = False):
+def surrounding_xy_ring(p,
+                        count = 12,
+                        radial_factor = 10.0,
+                        radial_distance = None,
+                        inner_ring = False,
+                        saucer_angle = None):
     """Creates a set of points surrounding the point set p, in the xy plane.
 
     arguments:
@@ -843,19 +862,27 @@ def surrounding_xy_ring(p, count = 12, radial_factor = 10.0, radial_distance = N
           results in a greater distance in which case that is used
        inner_ring (bool, default False): if True, an inner ring of points, with double count, is created
           at a radius just outside that of the furthest flung original point; this improves triangulation
-          of the extended point set when the original has a non-convex hull
+          of the extended point set when the original has a non-convex hull; radial_distance does not
+          effect the inner ring radius
+       saucer_angle (float, optional): if present, an angle in degrees, between +/- 90 (but less than 90 degrees)
+          being an angle to determine a z offset for the ring(s); a +ve angle results in a -ve z shift
 
     returns:
        numpy float array of shape (N, 3) being xyz points in surrounding ring(s); z is set constant to
-       mean value of z in p; N is count if inner_ring is False, 3 * count if True
+       mean value of z in p (optionally adjussted based on saucer_angle);
+       N is count if inner_ring is False, 3 * count if True
     """
 
-    def make_ring(count, centre, radius):
+    def make_ring(count, centre, radius, saucer_angle):
         delta_theta = 2.0 * maths.pi / float(count)
         ring = np.zeros((count, 3))
         for i in range(count):
             theta = float(i) * delta_theta
             ring[i] = centre + radius * np.array([maths.cos(theta), maths.sin(theta), 0.0])
+        if saucer_angle is not None and not maths.isclose(saucer_angle, 0.0):
+            assert abs(saucer_angle) < 90.0
+            z_shift = radius * maths.tan(vec.radians_from_degrees(saucer_angle))
+            ring[:, 2] -= z_shift
         return ring
 
     assert p.shape[-1] == 3
@@ -866,11 +893,11 @@ def surrounding_xy_ring(p, count = 12, radial_factor = 10.0, radial_distance = N
     radius = p_radius * radial_factor
     if radial_distance is not None and radial_distance > radius:
         radius = radial_distance
-    ring = make_ring(count, centre, radius)
+    ring = make_ring(count, centre, radius, saucer_angle)
     if inner_ring:
         inner_radius = p_radius * 1.1
         assert radius > inner_radius
-        in_ring = make_ring(2 * count, centre, inner_radius)
+        in_ring = make_ring(2 * count, centre, inner_radius, saucer_angle)
         return np.concatenate((in_ring, ring), axis = 0)
     return ring
 
@@ -893,7 +920,7 @@ def edges(t):
     """
 
     assert t.ndim == 2 and t.shape[1] == 3
-    all_edges = np.empty((len(t), 3, 2), dtype = int)
+    all_edges = np.empty((len(t), 3, 2), dtype = t.dtype)
     all_edges[:, :, 0] = t
     all_edges[:, :2, 1] = t[:, 1:]
     all_edges[:, 2, 1] = t[:, 0]
@@ -922,6 +949,7 @@ def triangles_using_edges(t, edges):
     """Returns int array of shape (len(edges), 2) with indices of upto 2 triangles using each edge (-1 for unused)."""
 
     assert t.ndim == 2 and t.shape[1] == 3 and edges.ndim == 2 and edges.shape[1] == 2
+    t_type = np.int32 if len(t) < 2_147_483_648 else np.int64
     ti = np.full((len(edges), 2), -1, dtype = int)
     for i in range(len(edges)):
         te = triangles_using_edge(t, edges[i, 0], edges[i, 1])
