@@ -568,7 +568,7 @@ def node_text(node, unknown_if_none = False):
 def node_bool(node):
     """Returns stripped node text as bool, or None."""
 
-    if node is None:
+    if node is None or node.text is None:
         return None
     return bool_from_text(node.text)
 
@@ -576,7 +576,7 @@ def node_bool(node):
 def node_int(node):
     """Returns stripped node text as int, or None."""
 
-    if node is None:
+    if node is None or node.text is None:
         return None
     text = node.text.strip()
     if text.lower() == 'none':
@@ -589,7 +589,7 @@ def node_int(node):
 def node_float(node):
     """Returns stripped node text as float, or None."""
 
-    if node is None:
+    if node is None or node.text is None:
         return None
     text = node.text.strip()
     if text.lower() == 'none':
@@ -778,6 +778,18 @@ def load_metadata_from_xml(node):
     return extra_metadata
 
 
+def find_metadata_item_node_in_xml(node, key):
+    """Returns the extra metadata node for a particular key, if present."""
+
+    if node is None:
+        return None
+    meta_nodes = list_of_tag(node, 'ExtraMetadata')
+    for meta in meta_nodes:
+        if find_tag_text(meta, 'Name') == key:
+            return meta
+    return None
+
+
 def create_metadata_xml(node, extra_metadata):
     """Writes the xml for the given metadata dictionary."""
 
