@@ -1,7 +1,8 @@
 """Class for RESQML Boundary Feature organizational objects."""
 
-from ._utils import alias_for_attribute, equivalent_extra_metadata
 import resqpy.olio.uuid as bu
+import resqpy.organize
+import resqpy.organize._utils as ou
 from resqpy.olio.base import BaseResqpy
 
 
@@ -9,12 +10,16 @@ class BoundaryFeature(BaseResqpy):
     """Class for RESQML Boundary Feature organizational objects."""
 
     resqml_type = "BoundaryFeature"
-    feature_name = alias_for_attribute("title")
+    feature_name = ou.alias_for_attribute("title")
 
-    def __init__(self, parent_model, uuid = None, feature_name = None, extra_metadata = None):
+    def __init__(self, parent_model, uuid = None, feature_name = None, originator = None, extra_metadata = None):
         """Initialises a boundary feature organisational object."""
 
-        super().__init__(model = parent_model, uuid = uuid, title = feature_name, extra_metadata = extra_metadata)
+        super().__init__(model = parent_model,
+                         uuid = uuid,
+                         title = feature_name,
+                         originator = originator,
+                         extra_metadata = extra_metadata)
 
     def is_equivalent(self, other, check_extra_metadata = True):
         """Returns True if this feature is essentially the same as the other; otherwise False."""
@@ -23,7 +28,7 @@ class BoundaryFeature(BaseResqpy):
             return False
         if self is other or bu.matching_uuids(self.uuid, other.uuid):
             return True
-        if check_extra_metadata and not equivalent_extra_metadata(self, other):
+        if check_extra_metadata and not ou.equivalent_extra_metadata(self, other):
             return False
         return self.feature_name == other.feature_name
 
