@@ -1,10 +1,9 @@
 """Class for RESQML Fluid Boundary Feature (contact) organizational objects."""
 
-from ._utils import (equivalent_extra_metadata, alias_for_attribute, extract_has_occurred_during,
-                     equivalent_chrono_pairs, create_xml_has_occurred_during)
-
 import resqpy.olio.uuid as bu
 import resqpy.olio.xml_et as rqet
+import resqpy.organize
+import resqpy.organize._utils as ou
 from resqpy.olio.base import BaseResqpy
 from resqpy.olio.xml_namespaces import curly_namespace as ns
 
@@ -13,14 +12,24 @@ class FluidBoundaryFeature(BaseResqpy):
     """Class for RESQML Fluid Boundary Feature (contact) organizational objects."""
 
     resqml_type = "FluidBoundaryFeature"
-    feature_name = alias_for_attribute("title")
+    feature_name = ou.alias_for_attribute("title")
     valid_kinds = ('free water contact', 'gas oil contact', 'gas water contact', 'seal', 'water oil contact')
 
-    def __init__(self, parent_model, uuid = None, kind = None, feature_name = None, extra_metadata = None):
+    def __init__(self,
+                 parent_model,
+                 uuid = None,
+                 kind = None,
+                 feature_name = None,
+                 originator = None,
+                 extra_metadata = None):
         """Initialises a fluid boundary feature (contact) organisational object."""
 
         self.kind = kind
-        super().__init__(model = parent_model, uuid = uuid, title = feature_name, extra_metadata = extra_metadata)
+        super().__init__(model = parent_model,
+                         uuid = uuid,
+                         title = feature_name,
+                         originator = originator,
+                         extra_metadata = extra_metadata)
 
     def is_equivalent(self, other, check_extra_metadata = True):
         """Returns True if this feature is essentially the same as the other; otherwise False."""
@@ -29,7 +38,7 @@ class FluidBoundaryFeature(BaseResqpy):
             return False
         if self is other or bu.matching_uuids(self.uuid, other.uuid):
             return True
-        if check_extra_metadata and not equivalent_extra_metadata(self, other):
+        if check_extra_metadata and not ou.equivalent_extra_metadata(self, other):
             return False
         return self.feature_name == other.feature_name and self.kind == other.kind
 
