@@ -18,7 +18,7 @@ import resqpy.property._collection_get_attributes as pcga
 def _add_selected_part_from_other_dict(collection, part, other, realization, support_uuid, uuid, continuous,
                                        categorical, count, points, indexable, property_kind, facet_type, facet,
                                        citation_title, citation_title_match_mode, time_series_uuid, time_index,
-                                       string_lookup_uuid, related_uuid, const_value, ignore_clashes):
+                                       string_lookup_uuid, related_uuid, const_value, extra, ignore_clashes):
     if _check_not_none_and_not_equals(realization, other.realization_for_part, part):
         return
     if _check_not_none_and_not_uuid_match(support_uuid, other.support_uuid_for_part, part):
@@ -55,6 +55,13 @@ def _add_selected_part_from_other_dict(collection, part, other, realization, sup
         assert other.model is not None
         if other.model.part(parts_list = [part], related_uuid = related_uuid) is None:
             return
+    if extra is not None and len(extra):
+        em = other.extra_metadata_for_part(part)
+        if em is None or len(em) < len(extra):
+            return
+        for key, value in extra.items():
+            if em.get(key) != value:
+                return
     if part in collection.dict.keys():
         if ignore_clashes:
             return
@@ -109,9 +116,15 @@ def _add_part_to_dict_get_uom(collection, part, continuous, xml_node, trust_uom,
     uom = None
     if continuous and not points:
         uom_node = rqet.find_tag(xml_node, 'UOM')
-        if uom_node is not None and (trust_uom or uom_node.text not in ['', 'Euc']):
-            uom = uom_node.text
-        else:
+        if uom_node is not None:
+            if uom_node.text == 'Euc':
+                em = rqet.load_metadata_from_xml(collection.model.root_for_part(part))
+                uom = em.get('Uom')
+                if uom is None and trust_uom:
+                    uom = 'Euc'
+            elif trust_uom or uom_node.text != '':
+                uom = uom_node.text
+        if uom is None:
             if not collection.guess_warning:
                 collection.guess_warning = True
                 log.warning("Guessing unit of measure for one or more properties")
@@ -135,7 +148,14 @@ def _check_not_none_and_not_equals(attrib, method, part):
 
 
 def _check_not_none_and_not_uuid_match(uuid, method, part):
-    return uuid is not None and not bu.matching_uuids(uuid, method(part))
+    if uuid is None:
+        return False
+    if isinstance(uuid, str):
+        if uuid == '*':
+            return method(part) is None
+        elif uuid == 'none':
+            return method(part) is not None
+    return not bu.matching_uuids(uuid, method(part))
 
 
 def _check_citation_title(citation_title, citation_title_match_mode, other, part):
@@ -179,7 +199,7 @@ def _process_imported_property(collection, attributes, property_kind_uuid, strin
                                extra_metadata, expand_const_arrays):
     (p_uuid, p_file_name, p_keyword, p_cached_name, p_discrete, p_uom, p_time_index, p_null_value, p_min_value,
      p_max_value, property_kind, facet_type, facet, realization, indexable_element, count, local_property_kind_uuid,
-     const_value, points, p_time_series_uuid) = attributes
+     const_value, points, p_time_series_uuid, p_string_lookup_uuid) = attributes
 
     log.debug('processing imported property ' + str(p_keyword))
     assert not points or not p_discrete
@@ -187,12 +207,14 @@ def _process_imported_property(collection, attributes, property_kind_uuid, strin
         local_property_kind_uuid = property_kind_uuid
     if not p_discrete:
         string_lookup_uuid = None
+    elif p_string_lookup_uuid is not None:
+        string_lookup_uuid = p_string_lookup_uuid
 
     property_kind = _process_imported_property_get_property_kind(collection, property_kind, local_property_kind_uuid,
                                                                  p_keyword, p_discrete, string_lookup_uuid, points)
 
     p_array = _process_imported_property_get_p_array(collection, p_cached_name)
-    p_array_bool = None if p_array is None else p_array.dtype in [bool, np.int8]
+    p_array_bool = isinstance(const_value, bool) if p_array is None else p_array.dtype in [bool, np.int8]
 
     add_min_max = pcga._process_imported_property_get_add_min_max(points, property_kind, string_lookup_uuid,
                                                                   local_property_kind_uuid, p_array_bool)
