@@ -31,12 +31,12 @@ def _min_max_of_cached_array(collection, cached_name, cached_array, null_value,
             if max_value is ma.masked:
                 max_value = None
     else:
-        min_value = np.nanmin(cached_array)
-        max_value = np.nanmax(cached_array)
-        if np.isnan(min_value):
+        if np.all(np.isnan(cached_array)):
             min_value = None
-        if np.isnan(max_value):
             max_value = None
+        else:
+            min_value = np.nanmin(cached_array)
+            max_value = np.nanmax(cached_array)
     return min_value, max_value
 
 
@@ -58,25 +58,26 @@ def _get_property_kind_uuid(collection, property_kind_uuid, property_kind, uom,
     return property_kind_uuid
 
 
-def _get_property_type_details(collection, discrete, string_lookup_uuid, points):
+def _get_property_type_details(discrete, string_lookup_uuid, points, null_value):
+    d_or_c_text = xsd_type = hdf5_type = None
     if discrete:
         if string_lookup_uuid is None:
-            collection.d_or_c_text = 'Discrete'
-
+            d_or_c_text = 'Discrete'
         else:
-            collection.d_or_c_text = 'Categorical'
-        collection.xsd_type = 'integer'
-        collection.hdf5_type = 'IntegerHdf5Array'
+            d_or_c_text = 'Categorical'
+        xsd_type = 'integer'
+        hdf5_type = 'IntegerHdf5Array'
     elif points:
-        collection.d_or_c_text = 'Points'
-        collection.xsd_type = 'double'
-        collection.hdf5_type = 'Point3dHdf5Array'
-        collection.null_value = None
+        d_or_c_text = 'Points'
+        xsd_type = 'double'
+        hdf5_type = 'Point3dHdf5Array'
+        null_value = None
     else:
-        collection.d_or_c_text = 'Continuous'
-        collection.xsd_type = 'double'
-        collection.hdf5_type = 'DoubleHdf5Array'
-        collection.null_value = None
+        d_or_c_text = 'Continuous'
+        xsd_type = 'double'
+        hdf5_type = 'DoubleHdf5Array'
+        null_value = None
+    return d_or_c_text, xsd_type, hdf5_type, null_value
 
 
 def _get_property_array_min_max_value(collection, property_array, const_value, discrete, min_value, max_value,
@@ -221,7 +222,7 @@ def _get_perm_k_part(collection, perms, perm_k_mode, share_perm_parts, perm_i_pa
                                                         uom = 'mD',
                                                         time_index = None,
                                                         null_value = None,
-                                                        property_kind = 'permeability rock',
+                                                        property_kind = 'rock permeability',
                                                         facet_type = 'direction',
                                                         facet = 'K',
                                                         realization = perms.realization_for_part(perm_i_part),
@@ -367,16 +368,20 @@ def _normalized_part_array_nan_if_masked(min_value, max_value, masked):
 
 
 def _normalized_part_array_use_logarithm(min_value, n_prop, masked):
-    if min_value <= 0.0:
-        n_prop[:] = np.where(n_prop < 0.0001, 0.0001, n_prop)
-    n_prop = np.log10(n_prop)
-    min_value = np.nanmin(n_prop)
-    max_value = np.nanmax(n_prop)
-    if masked:
-        if min_value is ma.masked:
-            min_value = np.nan
-        if max_value is ma.masked:
-            max_value = np.nan
+    if np.all(np.isnan(n_prop)):
+        min_value = np.nan
+        max_value = np.nan
+    else:
+        if min_value <= 0.0:
+            n_prop[:] = np.where(n_prop < 0.0001, 0.0001, n_prop)
+        n_prop = np.log10(n_prop)
+        min_value = np.nanmin(n_prop)
+        max_value = np.nanmax(n_prop)
+        if masked:
+            if min_value is ma.masked:
+                min_value = np.nan
+            if max_value is ma.masked:
+                max_value = np.nan
     return n_prop, min_value, max_value
 
 
@@ -402,6 +407,7 @@ def _normalized_part_array_fix_zero_at(min_value, max_value, n_prop, fix_zero_at
 
 
 def _supporting_shape_grid(support, indexable_element, direction):
+    shape_list = None
     if indexable_element is None or indexable_element == 'cells':
         shape_list = [support.nk, support.nj, support.ni]
     elif indexable_element == 'columns':
@@ -423,18 +429,33 @@ def _supporting_shape_grid(support, indexable_element, direction):
         shape_list = [support.nk, support.nj, support.ni, 2, 2, 2]
     elif indexable_element == 'nodes':
         shape_list = _supporting_shape_grid_nodes(support)
+    elif indexable_element == 'J0':
+        shape_list = [support.nk, support.ni]
+    elif indexable_element == 'I0':
+        shape_list = [support.nk, support.nj]
+    else:
+        raise ValueError(f'unsupported grid indexable element: {indexable_element}')
     return shape_list
 
 
 def _supporting_shape_grid_faces(direction, support):
-    assert direction is not None and direction.upper() in 'IJK'
-    axis = 'KJI'.index(direction.upper())
-    shape_list = [support.nk, support.nj, support.ni]
-    shape_list[axis] += 1  # note: properties for grid faces include outer faces
+    if direction is None:  # a composite 1D array (the RESQML standard)
+        count = 0
+        for axis in range(3):
+            batch = np.array(support.extent_kji, dtype = int)
+            batch[axis] += 1
+            count += np.prod(batch)
+        shape_list = [count]
+    else:
+        assert direction.upper() in 'IJK'
+        axis = 'KJI'.index(direction.upper())
+        shape_list = [support.nk, support.nj, support.ni]
+        shape_list[axis] += 1  # note: properties for grid faces include outer faces
     return shape_list
 
 
 def _supporting_shape_grid_nodes(support):
+    shape_list = None
     assert not support.k_gaps, 'indexable element of nodes not currently supported for grids with K gaps'
     if support.has_split_coordinate_lines:
         pillar_count = (support.nj + 1) * (support.ni + 1) + support.split_pillars_count
@@ -445,6 +466,7 @@ def _supporting_shape_grid_nodes(support):
 
 
 def _supporting_shape_wellboreframe(support, indexable_element):
+    shape_list = None
     if indexable_element is None or indexable_element == 'nodes':
         shape_list = [support.node_count]
     elif indexable_element == 'intervals':
@@ -453,6 +475,7 @@ def _supporting_shape_wellboreframe(support, indexable_element):
 
 
 def _supporting_shape_wellboremarkerframe(support, indexable_element):
+    shape_list = None
     if indexable_element is None or indexable_element == 'nodes':
         shape_list = [support.node_count]
     elif indexable_element == 'intervals':
@@ -461,6 +484,7 @@ def _supporting_shape_wellboremarkerframe(support, indexable_element):
 
 
 def _supporting_shape_blockedwell(support, indexable_element):
+    shape_list = None
     if indexable_element is None or indexable_element == 'intervals':
         shape_list = [support.node_count - 1]  # all intervals, including unblocked
     elif indexable_element == 'nodes':
@@ -471,6 +495,7 @@ def _supporting_shape_blockedwell(support, indexable_element):
 
 
 def _supporting_shape_mesh(support, indexable_element):
+    shape_list = None
     if indexable_element is None or indexable_element == 'cells' or indexable_element == 'columns':
         shape_list = [support.nj - 1, support.ni - 1]
     elif indexable_element == 'nodes':
@@ -479,7 +504,8 @@ def _supporting_shape_mesh(support, indexable_element):
 
 
 def _supporting_shape_surface(support, indexable_element):
-    if indexable_element is None or indexable_element == 'faces':
+    shape_list = None
+    if indexable_element is None or indexable_element in ['triangles', 'faces']:
         shape_list = [support.triangle_count()]
     elif indexable_element == 'nodes':
         shape_list = [support.node_count()]
@@ -487,14 +513,46 @@ def _supporting_shape_surface(support, indexable_element):
 
 
 def _supporting_shape_gridconnectionset(support, indexable_element):
+    shape_list = None
     if indexable_element is None or indexable_element == 'faces':
         shape_list = [support.count]
     return shape_list
 
 
+def _supporting_shape_polyline(support, indexable_element):
+    shape_list = None
+    if indexable_element is None or indexable_element == 'intervals':
+        shape_list = [len(support.coordinates) - (0 if support.isclosed else 1)]
+    elif indexable_element == 'nodes':
+        shape_list = [len(support.coordinates)]
+    return shape_list
+
+
+def _supporting_shape_polylineset(support, indexable_element):
+    shape_list = None
+    if indexable_element is None or indexable_element == 'intervals':
+        if support.boolnotconstant:
+            reduction = len(support.closed_array) - np.count_nonzero(support.closed_array)
+        else:
+            reduction = 0 if support.boolvalue else len(support.closed_array)
+        shape_list = [len(support.coordinates) - reduction]
+    elif indexable_element == 'nodes':
+        shape_list = [len(support.coordinates)]
+    return shape_list
+
+
+def _supporting_shape_pointset(support, indexable_element):
+    shape_list = None
+    if indexable_element is None or indexable_element == 'nodes':
+        shape_list = [len(support.full_array_ref())]
+    return shape_list
+
+
 def _supporting_shape_other(support, indexable_element):
     if indexable_element is None or indexable_element == 'cells':
         shape_list = [support.cell_count]
+    elif indexable_element == 'nodes':
+        shape_list = [support.node_count]
     elif indexable_element == 'faces per cell':
         support.cache_all_geometry_arrays()
         shape_list = [len(support.faces_per_cell)]
@@ -510,16 +568,23 @@ def _realizations_array_ref_get_r_extent(fill_missing, r_list):
 
 
 def _get_indexable_element(indexable_element, support_type):
+    # returns a default indexable element depending on the type of supporting representation
     if indexable_element is None:
         if support_type in [
                 'obj_IjkGridRepresentation', 'obj_BlockedWellboreRepresentation', 'obj_Grid2dRepresentation',
                 'obj_UnstructuredGridRepresentation'
         ]:
             indexable_element = 'cells'
-        elif support_type in ['obj_WellboreFrameRepresentation', 'obj_WellboreMarkerFrameRepresentation']:
-            indexable_element = 'nodes'  # note: could be 'intervals'
-        elif support_type in ['obj_GridConnectionSetRepresentation', 'obj_TriangulatedSetRepresentation']:
+        elif support_type in [
+                'obj_WellboreFrameRepresentation', 'obj_WellboreMarkerFrameRepresentation', 'obj_PointSetRepresentation'
+        ]:
+            indexable_element = 'nodes'  # note: could be 'intervals' (except for PointSet properties)
+        elif support_type == 'obj_GridConnectionSetRepresentation':
             indexable_element = 'faces'
+        elif support_type == 'obj_TriangulatedSetRepresentation':
+            indexable_element = 'triangles'
+        elif support_type in ['obj_PolylineRepresentation', 'obj_PolylineSetRepresentation']:
+            indexable_element = 'intervals'  # could also be 'nodes'
         else:
             raise Exception('indexable element unknown for unsupported supporting representation object')
     return indexable_element
@@ -545,7 +610,7 @@ def _cached_part_array_ref_const_none(collection, part, dtype, model, cached_arr
     # the required shape is required if a bool array may need to be unpacked from bits
     required_shape = None
     str_dtype = str(dtype)
-    if use_pack and ('bool' in str_dtype or 'int8' in str_dtype):
+    if use_pack and ('bool' in str_dtype or 'uint8' in str_dtype):
         required_shape = collection.supporting_shape(indexable_element = collection.indexable_for_part(part),
                                                      direction = _part_direction(collection, part))
 
@@ -577,12 +642,16 @@ def _normalized_part_array_get_minmax(collection, trust_min_max, part, p_array,
         min_value = collection.minimum_value_for_part(part)
         max_value = collection.maximum_value_for_part(part)
     if min_value is None or max_value is None:
-        min_value = np.nanmin(p_array)
-        if masked and min_value is ma.masked:
+        if np.all(np.isnan(p_array)):
             min_value = None
-        max_value = np.nanmax(p_array)
-        if masked and max_value is ma.masked:
             max_value = None
+        else:
+            min_value = np.nanmin(p_array)
+            if masked and min_value is ma.masked:
+                min_value = None
+            max_value = np.nanmax(p_array)
+            if masked and max_value is ma.masked:
+                max_value = None
         collection.override_min_max(part, min_value, max_value)  # NB: this does not modify xml
     return min_value, max_value
 
