@@ -12,18 +12,13 @@ import numpy as np
 import resqpy.property as rqp
 import resqpy.olio.uuid as bu
 import resqpy.olio.xml_et as rqet
-import resqpy.weights_and_measures as bwam
+import resqpy.weights_and_measures as wam
 
 # the following resqml property kinds and facet types are 'known about' by this module in relation to nexus
 # other property kinds should be handled okay but without any special treatment
 # see property_kind_and_facet_from_keyword() for simulator keyword to property kind and facet mapping
 
-supported_property_kind_list = [
-    'continuous', 'discrete', 'categorical', 'code', 'index', 'depth', 'rock volume', 'pore volume', 'volume',
-    'thickness', 'length', 'cell length', 'area', 'net to gross ratio', 'porosity', 'permeability thickness',
-    'permeability length', 'permeability rock', 'rock permeability', 'fluid volume', 'transmissibility', 'pressure',
-    'saturation', 'solution gas-oil ratio', 'vapor oil-gas ratio', 'property multiplier', 'thermodynamic temperature'
-]
+supported_property_kind_list = list(wam.valid_property_kinds())
 
 supported_local_property_kind_list = [
     'active', 'transmissibility multiplier', 'fault transmissibility', 'mat transmissibility'
@@ -78,7 +73,7 @@ expected_facet_type_dict = {
     'property multiplier': (
         'what',
         [
-            'rock volume',  # made up; todo: add rock permeability?
+            'rock volume',  # made up; todo: add rock permeability? (would need multiple facets)
             'pore volume',
             'transmissibility'
         ]),
@@ -159,7 +154,7 @@ def property_kind_and_facet_from_keyword(keyword):
     elif len(lk) >= 2 and lk[0] == 'd' and lk[1] in 'xyz':
         property_kind, facet_type, facet = _pkf_from_keyword_length(lk)
     elif lk[:4] == 'perm' or (len(lk) == 2 and lk[0] == 'k'):  # permeability
-        property_kind = 'permeability rock'
+        property_kind = 'rock permeability'
         (facet_type, facet) = _facet_info_for_dir_ch(lk[-1])
     elif lk[:5] == 'trans' or (len(lk) == 2 and lk[0] == 't'):  # transmissibility (for unit viscosity)
         if 'mult' in lk:
@@ -326,7 +321,7 @@ def infer_property_kind(name, unit):
 
     # Currently unit is ignored
 
-    valid_kinds = bwam.valid_property_kinds()
+    valid_kinds = wam.valid_property_kinds()
 
     if name in valid_kinds:
         kind = name
@@ -522,7 +517,8 @@ def selective_version_of_collection(collection,
                                     title = None,
                                     title_mode = None,
                                     related_uuid = None,
-                                    const_value = None):
+                                    const_value = None,
+                                    extra = None):
     """Returns a new PropertyCollection with those parts which match all arguments that are not None.
 
     arguments:
@@ -549,6 +545,7 @@ def selective_version_of_collection(collection,
            if not specified and title or citation_title argument is present
        related_uuid (UUID or str, optional): only properties with direct relationship to this uuid are selected
        const_value (float or int, optional): only properties flagged as constant, with given value, are selected
+       extra (dict, optional): only properties where the extra metadata includes all the items of this dict are selected
 
     returns:
        a new PropertyCollection containing those properties which match the filter parameters that are not None
@@ -594,7 +591,8 @@ def selective_version_of_collection(collection,
                                                          string_lookup_uuid = string_lookup_uuid,
                                                          categorical = categorical,
                                                          related_uuid = related_uuid,
-                                                         const_value = const_value)
+                                                         const_value = const_value,
+                                                         extra = extra)
     return view
 
 
@@ -814,7 +812,8 @@ def property_parts(model,
         for part in parts:
             root = model.root_for_part(part)
             if facet_match(root, facet_type, facet):
-                pk_parts.append(part)
+                f_parts.append(part)
+        parts = f_parts
     return parts
 
 
