@@ -14,6 +14,7 @@ import resqpy.olio.uuid as bu
 import resqpy.olio.vector_utilities as vec
 import resqpy.olio.write_hdf5 as rwh5
 import resqpy.olio.xml_et as rqet
+import resqpy.property as rqp
 import resqpy.surface
 import resqpy.surface._base_surface as rqsb
 from resqpy.olio.xml_namespaces import curly_namespace as ns
@@ -37,7 +38,8 @@ class PointSet(rqsb.BaseSurface):
                  irap_file = None,
                  title = None,
                  originator = None,
-                 extra_metadata = None):
+                 extra_metadata = None,
+                 remove_trailing_999 = True):
         """Creates an empty Point Set object and optionally populates from xml or other source.
 
         arguments:
@@ -65,6 +67,8 @@ class PointSet(rqsb.BaseSurface):
               ignored if uuid is not None
            extra_metadata (dict, optional): string key, value pairs to add as extra metadata for the point set;
               ignored if uuid is not None
+           remove_trailing_999 (bool, default True): if True, when loading from an irap_file, if the last point
+              in the file is triple 999.0, then it is excluded from the point set
 
         returns:
            newly created PointSet object
@@ -78,6 +82,7 @@ class PointSet(rqsb.BaseSurface):
         self.patch_array_list = []  # ordered list of numpy float arrays (or None before loading), each of shape (N, 3)
         self.full_array = None  # composite points (all patches)
         self.represented_interpretation_root = None
+        self.property_collection = None
         super().__init__(model = parent_model,
                          uuid = uuid,
                          title = title,
@@ -102,7 +107,7 @@ class PointSet(rqsb.BaseSurface):
             self.from_charisma(charisma_file)
 
         elif irap_file is not None:  # Points from IRAP simple points
-            self.from_irap(irap_file)
+            self.from_irap(irap_file, remove_trailing_999)
 
         if not self.title:
             self.title = 'point set'
@@ -146,21 +151,22 @@ class PointSet(rqsb.BaseSurface):
         if not self.title:
             self.title = charisma_file
 
-    def from_irap(self, irap_file):
+    def from_irap(self, irap_file, remove_trailing_999 = True):
         """Instantiate a pointset using points from an input irap file.
 
         arguments:
-            irap_file: a IRAP classic points format file
+            irap_file (str): an existing IRAP classic points format file
+            remove_trailing_999 (bool, default True): if True, and the last point in the irap file is triple 999.0, then
+                it is excluded
         """
         with open(irap_file, 'r') as points:
             cpoints = np.loadtxt(points, encoding = 'uft-8')
-            # for i, line in enumerate(points.readlines()):
-            #     if i == 0:
-            #         cpoints = np.array([[float(x) for x in line.split(" ")]])
-            #     else:
-            #         curr = np.array([[float(x) for x in line.split(" ")]])
-            #         cpoints = np.concatenate((cpoints, curr))
-        self.add_patch(cpoints)
+        assert len(cpoints), f'no points loaded from irap file: {irap_file}'
+        assert cpoints.ndim == 2 and cpoints.shape[1] == 3
+        if remove_trailing_999 and np.all(np.isclose(cpoints[-1], 999.0)):
+            self.add_patch(cpoints[:-1])
+        else:
+            self.add_patch(cpoints)
         assert self.crs_uuid is not None, 'crs uuid missing when establishing point set from irap file'
         if not self.title:
             self.title = irap_file
@@ -219,7 +225,12 @@ class PointSet(rqsb.BaseSurface):
             self.title = polyset.title
 
     def check_crs_match(self, crs_uuid):
-        """Checks if the model crs_uuid matches a given crs_uuid. If the current model crs_uuid is None, the new crs_uuid is used as the model crs_uuid. If a mismatch is found an assertion error is raised."""
+        """Checks if the point set's crs_uuid matches a given crs_uuid.
+
+        notes:
+            if the current model crs_uuid is None, the new crs_uuid is used as the model crs_uuid;
+            if a mismatch is found an assertion error is raised
+        """
         if self.crs_uuid is None:
             self.crs_uuid = crs_uuid
         else:
@@ -246,8 +257,8 @@ class PointSet(rqsb.BaseSurface):
                                         dtype = 'float')
         except Exception:
             log.exception('hdf5 points failure for point set patch ' + str(patch_index))
-        assert self.temp_points.ndim == 2 and self.temp_points.shape[
-            1] == 3, 'unsupported dimensionality to points array'
+        assert self.temp_points.ndim == 2 and self.temp_points.shape[1] == 3,  \
+            'unsupported dimensionality to points array'
         self.patch_array_list[patch_index] = self.temp_points.copy()
         delattr(self, 'temp_points')
         return self.patch_array_list[patch_index]
@@ -391,12 +402,31 @@ class PointSet(rqsb.BaseSurface):
             p[..., :2] = points_array
             points_array = p
         self.patch_array_list.append(points_array.reshape(-1, 3).copy())
-        self.patch_ref_list.append((None, None, points_array.shape[0]))
+        self.patch_ref_list.append((None, None, points_array.size // 3))
         self.full_array = None
         if self.patch_count is None:
             self.patch_count = 0
         self.patch_count += 1
 
+    def extract_property_collection(self, refresh = False):
+        """Returns a property collection for the point set.
+
+        arguments:
+            refresh (bool, default False): if True, the property collection is refreshed
+                from the current state of the model; if False and the property collection
+                has already been cached for the point set, then the cached copy is used
+
+        returns:
+            a PropertyCollection holding those properties in the model where this point set
+            is the supporting representation
+
+        note:
+            point set properties have indexable element of 'nodes'
+        """
+        if self.property_collection is None or refresh:
+            self.property_collection = rqp.PropertyCollection(support = self)
+        return self.property_collection
+
     def write_hdf5(self, file_name = None, mode = 'a'):
         """Create or append to an hdf5 file, writing datasets for the point set patches after caching arrays.
 
