@@ -122,10 +122,23 @@ class Surface(rqsb.BaseSurface):
             self.set_from_mesh_file(mesh_file, mesh_format, quad_triangles = quad_triangles)
         elif tsurf_file is not None:
             self.set_from_tsurf_file(tsurf_file)
+        self._load_normal_vector_from_extra_metadata()
 
     @classmethod
-    def from_tri_mesh(cls, tri_mesh):
-        """Create a Surface from a TriMesh."""
+    def from_tri_mesh(cls, tri_mesh, exclude_nans = False):
+        """Create a Surface from a TriMesh.
+
+        arguments:
+            tri_mesh (TriMesh): the tri mesh for which an equivalent Surface is required
+            exclude_nans (bool, default False): if True, and tri mesh point involving a not-a-number is
+                excluded from the surface points, along with any triangle that has such a point as a vertex
+
+        returns:
+            a new Surface using the points and triangles of the tri mesh
+
+        note:
+            this method does not write hdf5 data nor create xml for the new Surface
+        """
         assert isinstance(tri_mesh, rqs.TriMesh)
         surf = cls(tri_mesh.model,
                    crs_uuid = tri_mesh.crs_uuid,
@@ -133,10 +146,82 @@ class Surface(rqsb.BaseSurface):
                    surface_role = tri_mesh.surface_role,
                    extra_metadata = tri_mesh.extra_metadata if hasattr(tri_mesh, 'extra_metadata') else None)
         t, p = tri_mesh.triangles_and_points()
+        if exclude_nans:
+            t, p = nan_removed_triangles_and_points(t, p)
         surf.set_from_triangles_and_points(t, p)
         surf.represented_interpretation_root = tri_mesh.represented_interpretation_root
         return surf
 
+    @classmethod
+    def from_downsampling_surface(cls,
+                                  fine_surface,
+                                  point_count = None,
+                                  title = None,
+                                  target_model = None,
+                                  inherit_extra_metadata = True,
+                                  inherit_represented_interpretation = True,
+                                  convexity_parameter = 5.0):
+        """Create a Surface by taking a random subset of points from an existing surface and re-triangulating.
+
+        arguments:
+           fine_surface (Surface): a finely triangulated existing surface
+           point_count (int, optional): the number of randomly selected points to keep; defaults to 1% of
+              the fine surface point count
+           title (str, optional): the title for the new (coarse) surface; defaults to the title of the
+              fine surface
+           target_model (Model, optional): the model to receive the new surface; defaults to that of the
+              fine surface
+           inherit_extra_metadata (bool, default True): if True, the coarse surface will inherit any extra
+              metadata that the fine surface has
+           inherit_represented_interpretation (bool, default True): if True and the fine surface has a
+              represented interpretation then it is inherited by the coarse surface
+           convexity_parameter (float, default 5.0): controls how likely the resulting triangulation is to be
+              convex; reduce to 1.0 to allow slightly more concavities; increase to 100.0 or more for very
+              little chance of even a slight concavity
+
+        returns:
+            new Surface, without its hdf5 having been written, nor xml created
+
+        note:
+            if the fine surface does not have more points than point count, then a copy of that surface
+            is returned without re-triangulating
+        """
+
+        assert fine_surface is not None
+        if title is None:
+            title = fine_surface.title
+        inter_model = target_model is not None and target_model is not fine_surface.model
+        if target_model is None:
+            target_model = fine_surface.model
+        fine_t, fine_p = fine_surface.triangles_and_points()
+        if point_count is None:
+            point_count = len(fine_p) // 100
+        if point_count < 3:
+            point_count = 3
+        if inter_model:
+            target_model.copy_uuid_from_other_model(fine_surface.model, fine_surface.crs_uuid)
+            if inherit_represented_interpretation and fine_surface.represented_interpretation_root is not None:
+                ri_uuid = fine_surface.model.uuid_for_root(fine_surface.represented_interpretation_root)
+                target_model.copy_uuid_from_other_model(fine_surface.model, ri_uuid)
+        em = (fine_surface.extra_metadata
+              if inherit_extra_metadata and hasattr(fine_surface, 'extra_metadata') else None)
+        surf = cls(target_model,
+                   crs_uuid = fine_surface.crs_uuid,
+                   title = title,
+                   surface_role = fine_surface.surface_role,
+                   extra_metadata = em)
+        if point_count >= len(fine_p):
+            t, p = fine_t, fine_p
+        else:
+            p = fine_p.copy()
+            np.random.default_rng().shuffle(p, axis = 0)
+            p = p[:point_count]
+            t = triangulate.dt(p[:, :2], container_size_factor = convexity_parameter, algorithm = "scipy")
+        surf.set_from_triangles_and_points(t, p)
+        if inherit_represented_interpretation:
+            surf.represented_interpretation_root = fine_surface.represented_interpretation_root
+        return surf
+
     def _load_from_xml(self):
         root_node = self.root
         assert root_node is not None
@@ -188,49 +273,97 @@ class Surface(rqsb.BaseSurface):
 
         self.model = parent_model
 
-    def triangles_and_points(self):
-        """Returns arrays representing combination of all the patches in the surface.
+    def number_of_patches(self):
+        """Returns the number of patches present in the surface."""
 
-        Returns:
-           Tuple (triangles, points):
+        self.extract_patches(self.root)
+        return len(self.patch_list)
 
-           * triangles (int array of shape[:, 3]): integer indices into points array,
-             being the nodes of the corners of the triangles
-           * points (float array of shape[:, 3]): flat array of xyz points, indexed by triangles
+    def triangles_and_points(self, patch = None, copy = False):
+        """Returns arrays representing one patch or a combination of all the patches in the surface.
+
+        arguments:
+           patch (int, optional): patch index; if None, combined arrays for all patches are returned
+           copy (bool, default False): if True, a copy of the arrays is returned; if False, the cached
+              arrays are returned
+
+        returns:
+           tuple (triangles, points):
+              triangles (int array of shape[:, 3]): integer indices into points array,
+                 being the nodes of the corners of the triangles;
+              points (float array of shape[:, 3]): flat array of xyz points, indexed by triangles
 
         :meta common:
         """
 
-        if self.triangles is not None:
-            return (self.triangles, self.points)
         self.extract_patches(self.root)
-        points_offset = 0
-        for triangulated_patch in self.patch_list:
-            (t, p) = triangulated_patch.triangles_and_points()
-            if points_offset == 0:
-                self.triangles = t.copy()
-                self.points = p.copy()
+        if patch is None:
+            if self.triangles is None or self.points is None:
+                if self.triangles is None:
+                    points_offset = 0
+                    for triangulated_patch in self.patch_list:
+                        (t, p) = triangulated_patch.triangles_and_points()
+                        if points_offset == 0:
+                            self.triangles = t
+                            self.points = p
+                        else:
+                            self.triangles = np.concatenate((self.triangles, t.copy() + points_offset))
+                            self.points = np.concatenate((self.points, p))
+                        points_offset += p.shape[0]
+            if copy:
+                return (self.triangles.copy(), self.points.copy())
             else:
-                self.triangles = np.concatenate((self.triangles, t.copy() + points_offset))
-                self.points = np.concatenate((self.points, p.copy()))
-            points_offset += p.shape[0]
-        return (self.triangles, self.points)
+                return (self.triangles, self.points)
+        assert 0 <= patch < len(self.patch_list),  \
+            ValueError(f'patch index {patch} out of range for surface with {len(self.patch_list)} patches')
+        return self.patch_list[patch].triangles_and_points(copy = copy)
 
-    def triangle_count(self):
-        """Return the numner of triangles in this surface."""
+    def decache_triangles_and_points(self):
+        """Removes the cached composite triangles and points arrays."""
+        self.points = None
+        self.triangles = None
+
+    def triangle_count(self, patch = None):
+        """Return the numner of triangles in this surface, or in one patch.
+
+        arguments:
+           patch (int, optional): patch index; if None, a combined triangle count for all patches is returned
+
+        returns:
+           int being the number of trianges in the patch (if specified) or in all the patches
+        """
 
         self.extract_patches(self.root)
-        if not self.patch_list:
-            return 0
-        return np.sum([tp.triangle_count for tp in self.patch_list])
+        if patch is None:
+            if not self.patch_list:
+                return 0
+            return np.sum([tp.triangle_count for tp in self.patch_list])
+        assert 0 <= patch < len(self.patch_list),  \
+            ValueError(f'patch index {patch} out of range for surface with {len(self.patch_list)} patches in triangle_count')
+        return self.patch_list[patch].triangle_count
 
-    def node_count(self):
-        """Return the number of nodes (points) used in this surface."""
+    def node_count(self, patch = None):
+        """Return the number of nodes (points) used in this surface, or in one patch.
+
+        arguments:
+           patch (int, optional): patch index; if None, a combined node count for all patches is returned
+
+        returns:
+           int being the number of nodes in the patch (if specified) or in all the patches
+
+        note:
+           a multi patch surface might have more than one node colocated; this method will treat such coincident nodes
+           as separate nodes
+        """
 
         self.extract_patches(self.root)
-        if not self.patch_list:
-            return 0
-        return np.sum([tp.node_count for tp in self.patch_list])
+        if patch is None:
+            if not self.patch_list:
+                return 0
+            return np.sum([tp.node_count for tp in self.patch_list])
+        assert 0 <= patch < len(self.patch_list),  \
+            ValueError(f'patch index {patch} out of range for surface with {len(self.patch_list)} patches in node_count')
+        return self.patch_list[patch].node_count
 
     def change_crs(self, required_crs):
         """Changes the crs of the surface, also sets a new uuid if crs changed.
@@ -298,7 +431,7 @@ class Surface(rqsb.BaseSurface):
         self.uuid = bu.new_uuid()
 
     def set_to_split_surface(self, large_surface, line, delta_xyz):
-        """Populate this (empty) surface with a version of a larger surface split by an xy line.
+        """Populate this (empty) surface with a version of a larger surface split by a straight xy line.
 
         arguments:
             large_surface (Surface): the larger surface, a copy of which is to be split
@@ -316,13 +449,14 @@ class Surface(rqsb.BaseSurface):
         t, p = large_surface.triangles_and_points()
         assert p.ndim == 2 and p.shape[1] == 3
         pp = np.concatenate((p, line), axis = 0)
-        tp = np.empty(p.shape, dtype = int)
+        t_type = np.int32 if len(pp) <= 2_147_483_647 else np.int64
+        tp = np.empty(p.shape, dtype = t_type)
         tp[:, 0] = len(p)
         tp[:, 1] = len(p) + 1
-        tp[:, 2] = np.arange(len(p), dtype = int)
+        tp[:, 2] = np.arange(len(p), dtype = t_type)
         cw = vec.clockwise_triangles(pp, tp)
-        pai = np.where(cw >= 0.0, True, False)  # bool mask over p
-        pbi = np.where(cw <= 0.0, True, False)  # bool mask over p
+        pai = (cw >= 0.0)  # bool mask over p
+        pbi = (cw <= 0.0)  # bool mask over p
         tap = pai[t]
         tbp = pbi[t]
         ta = np.any(tap, axis = 1)  # bool array over t
@@ -331,11 +465,11 @@ class Surface(rqsb.BaseSurface):
         # here we stick the two halves together into a single patch
         # todo: keep as two patches as required by RESQML business rules
         p_combo = np.empty((0, 3))
-        t_combo = np.empty((0, 3), dtype = int)
+        t_combo = np.empty((0, 3), dtype = t_type)
         for i, tab in enumerate((ta, tb)):
             p_keep = np.unique(t[tab])
             # note new point index for each old point that is being kept
-            p_map = np.full(len(p), -1, dtype = int)
+            p_map = np.full(len(p), -1, dtype = t_type)
             p_map[p_keep] = np.arange(len(p_keep))
             # copy those unique points into a trimmed points array
             points_trimmed = p[p_keep].copy()
@@ -352,17 +486,24 @@ class Surface(rqsb.BaseSurface):
 
         self.set_from_triangles_and_points(t_combo, p_combo)
 
-    def distinct_edges(self):
-        """Returns a numpy int array of shape (N, 2) being the ordered node pairs of distinct edges of triangles."""
+    def distinct_edges(self, patch = None):
+        """Returns a numpy int array of shape (N, 2) being the ordered node pairs of distinct edges of triangles.
 
-        triangles, _ = self.triangles_and_points()
+        arguments:
+           patch (int, optional): patch index; if None, a combination of edges for all patches is returned
+        """
+
+        triangles, _ = self.triangles_and_points(patch = patch)
         assert triangles is not None
         unique_edges, _ = triangulate.edges(triangles)
         return unique_edges
 
-    def distinct_edges_and_counts(self):
+    def distinct_edges_and_counts(self, patch = None):
         """Returns unique edges as pairs of point indices, and a count of uses of each edge.
 
+        arguments:
+           patch (int, optional): patch index; if None, combined results for all patches are returned
+
         returns:
             numpy int array of shape (N, 2), numpy int array of shape (N,)
             where 2D array is list-like sorted points index pairs for unique edges
@@ -370,14 +511,39 @@ class Surface(rqsb.BaseSurface):
 
         notes:
             first entry in each pair is always the lower of the two point indices;
-            for well formed surfaces, the count should everywhere be zero or one;
+            for well formed surfaces, the count should everywhere be one or two;
             the function does not attempt to detect coincident points
         """
 
-        triangles, _ = self.triangles_and_points()
+        triangles, _ = self.triangles_and_points(patch = patch)
         assert triangles is not None
         return triangulate.edges(triangles)
 
+    def edge_lengths(self, required_uom = None, patch = None):
+        """Returns float array of shape (N, 3) being triangle edge lengths.
+
+        arguments:
+            required_uom (str, optional): the required length uom for the resulting edge lengths; default is crs xy units
+            patch (int, optional): patch index; if None, edge lengths for all patches are returned
+
+        returns:
+            numpy float array of shape (N, 3) where N is the number of triangles
+        """
+
+        t, p = self.triangles_and_points(patch = patch)
+        crs = rqc.Crs(self.model, uuid = self.crs_uuid)
+        if required_uom is None:
+            required_uom = crs.xy_units
+        if crs.xy_units != required_uom or crs.z_units != required_uom:
+            p = p.copy()
+            wam.convert_lengths(p[:, :2], crs.xy_units, required_uom)
+            wam.convert_lengths(p[:, 2], crs.z_units, required_uom)
+        t_end = np.empty_like(t)
+        t_end[:, :2] = t[:, 1:]
+        t_end[:, 2] = t[:, 0]
+        edge_v = p[t_end, :] - p[t, :]
+        return vec.naive_lengths(edge_v)
+
     def set_from_triangles_and_points(self, triangles, points):
         """Populate this (empty) Surface object from an array of triangle corner indices and an array of points."""
 
@@ -385,6 +551,22 @@ class Surface(rqsb.BaseSurface):
         tri_patch.set_from_triangles_and_points(triangles, points)
         self.patch_list = [tri_patch]
         self.uuid = bu.new_uuid()
+        self.triangles = triangles.copy()
+        self.points = points.copy()
+
+    def set_multi_patch_from_triangles_and_points(self, triangles_and_points_list):
+        """Populate this (empty) Surface object from a list of paits: array of triangle corner indices, array of points."""
+
+        self.patch_list = []
+        self.trianges = None
+        self.points = None
+        for patch, entry in enumerate(triangles_and_points_list):
+            assert len(entry) == 2, 'expecting pair of arrays (triangles, points) for each patch'
+            triangles, points = entry
+            tri_patch = rqstp.TriangulatedPatch(self.model, patch_index = patch, crs_uuid = self.crs_uuid)
+            tri_patch.set_from_triangles_and_points(triangles, points)
+            self.patch_list.append(tri_patch)
+        self.uuid = bu.new_uuid()
 
     def set_from_point_set(self,
                            point_set,
@@ -420,10 +602,9 @@ class Surface(rqsb.BaseSurface):
            flange_inner_ring (bool, default False): if True, an inner ring of points, with double flange point counr,
               is created at a radius just outside that of the furthest flung original point; this improves
               triangulation of the extended point set when the original has a non-convex hull
-           saucer_parameter (float, optional): if present, and extend_with_flange is True, then the fractional
-              distance from the centre of the points to its rim at which to sample the surface for extrapolation
-              and thereby modify the recumbent z of flange points; 0 will usually give shallower and smoother saucer;
-              larger values (must be less than one) will lead to stronger and more erratic saucer shape in flange
+           saucer_parameter (float, optional): if present, and extend_with_flange is True, then a parameter
+              controlling the shift of flange points in a perpendicular direction away from the fault plane;
+              see notes for how this parameter is interpreted
            make_clockwise (bool, default False): if True, the returned triangles will all be clockwise when
               viewed in the direction -ve to +ve z axis; if reorient is also True, the clockwise aspect is
               enforced in the reoriented space
@@ -437,12 +618,36 @@ class Surface(rqsb.BaseSurface):
            set to False (zero) for non-flange triangles and True (one) for flange triangles; this array is
            suitable for adding as a property for the surface, with indexable element 'faces';
            when flange extension occurs, the radius is the greater of the values determined from the radial factor
-           and radial distance arguments
+           and radial distance arguments;
+           the saucer_parameter is interpreted in one of two ways: (1) +ve fractoinal values between zero and one
+           are the fractional distance from the centre of the points to its rim at which to sample the surface for
+           extrapolation and thereby modify the recumbent z of flange points; 0 will usually give shallower and
+           smoother saucer; larger values (must be less than one) will lead to stronger and more erratic saucer
+           shape in flange; (2) other values between -90.0 and 90.0 are interpreted as an angle to apply out of
+           the plane of the original points, to give a simple (and less computationally demanding) saucer shape;
+           +ve angles result in the shift being in the direction of the -ve z hemisphere; -ve angles result in
+           the shift being in the +ve z hemisphere; in either case the direction of the shift is perpendicular
+           to the average plane of the original points
         """
 
+        simple_saucer_angle = None
+        if saucer_parameter is not None and (saucer_parameter > 1.0 or saucer_parameter < 0.0):
+            assert -90.0 < saucer_parameter < 90.0, f'simple saucer angle parameter must be less than 90 degrees; too big: {saucer_parameter}'
+            simple_saucer_angle = saucer_parameter
+            saucer_parameter = None
         assert saucer_parameter is None or 0.0 <= saucer_parameter < 1.0
         crs = rqc.Crs(self.model, uuid = point_set.crs_uuid)
         p = point_set.full_array_ref()
+        assert p.ndim >= 2
+        assert p.shape[-1] == 3
+        p = p.reshape((-1, 3))
+        nan_mask = np.isnan(p)
+        if np.any(nan_mask):
+            row_mask = np.logical_not(np.any(nan_mask, axis = -1))
+            log.info(
+                f'removing {len(p) - np.count_nonzero(row_mask)} NaN points from point set {point_set.title} prior to surface triangulation'
+            )
+            p = p[row_mask, :]
         if crs.xy_units == crs.z_units or not reorient:
             unit_adjusted_p = p
         else:
@@ -455,12 +660,15 @@ class Surface(rqsb.BaseSurface):
             p_xy = unit_adjusted_p
         if extend_with_flange:
             if not reorient:
+                assert saucer_parameter is None and simple_saucer_angle is None,  \
+                    'flange saucer mode only available with reorientation active'
                 log.warning('extending point set with flange without reorientation')
             flange_points = triangulate.surrounding_xy_ring(p_xy,
                                                             count = flange_point_count,
                                                             radial_factor = flange_radial_factor,
                                                             radial_distance = flange_radial_distance,
-                                                            inner_ring = flange_inner_ring)
+                                                            inner_ring = flange_inner_ring,
+                                                            saucer_angle = simple_saucer_angle)
             p_xy_e = np.concatenate((p_xy, flange_points), axis = 0)
             if reorient:
                 # reorient back extenstion points into original p space
@@ -490,7 +698,6 @@ class Surface(rqsb.BaseSurface):
             flange_array = np.zeros(len(t), dtype = bool)
             flange_array[:] = np.where(np.any(t >= len(p), axis = 1), True, False)
             if saucer_parameter is not None:
-                assert reorient, 'flange saucer mode only available with reorientation active'
                 _adjust_flange_z(self.model, self.crs_uuid, p_xy_e, len(p), t, flange_array, saucer_parameter)
                 p_e = vec.rotate_array(reorient_matrix.T, p_xy_e)
         if crs.xy_units != crs.z_units and reorient:
@@ -521,7 +728,7 @@ class Surface(rqsb.BaseSurface):
 
         _, p = self.triangles_and_points()
         crs = rqc.Crs(self.model, uuid = self.crs_uuid)
-        if crs.xy_units == self.z_units:
+        if crs.xy_units == crs.z_units:
             return p
         unit_adjusted_p = p.copy()
         wam.convert_lengths(unit_adjusted_p[:, 2], crs.z_units, crs.xy_units)
@@ -742,7 +949,7 @@ class Surface(rqsb.BaseSurface):
             v_index = None
             for line in lines:
                 if "VRTX" in line:
-                    words = line.rstrip().split(" ")
+                    words = line.rstrip().split()
                     v_i = int(words[1])
                     if v_index is None:
                         v_index = v_i
@@ -752,10 +959,11 @@ class Surface(rqsb.BaseSurface):
                         v_index = v_i
                     vertices.append(words[2:5])
                 elif "TRGL" in line:
-                    triangles.append(line.rstrip().split(" ")[1:4])
+                    triangles.append(line.rstrip().split()[1:4])
         assert len(vertices) >= 3, 'vertices missing'
         assert len(triangles) > 0, 'triangles missing'
-        triangles = np.array(triangles, dtype = int) - index_offset
+        t_type = np.int32 if len(vertices) <= 2_147_483_647 else np.int64
+        triangles = np.array(triangles, dtype = t_type) - index_offset
         vertices = np.array(vertices, dtype = float)
         assert np.all(triangles >= 0) and np.all(triangles < len(vertices)), 'triangle vertex indices out of range'
         self.set_from_triangles_and_points(triangles = triangles, points = vertices)
@@ -793,10 +1001,10 @@ class Surface(rqsb.BaseSurface):
         for patch in self.patch_list:
             patch.vertical_rescale_points(ref_depth, scaling_factor)
 
-    def line_intersection(self, line_p, line_v, line_segment = False):
+    def line_intersection(self, line_p, line_v, line_segment = False, patch = None):
         """Returns x,y,z of an intersection point of straight line with the surface, or None if no intersection found."""
 
-        t, p = self.triangles_and_points()
+        t, p = self.triangles_and_points(patch = patch)
         tp = p[t]
         intersects = meet.line_triangles_intersects(line_p, line_v, tp, line_segment = line_segment)
         indices = meet.intersects_indices(intersects)
@@ -804,21 +1012,22 @@ class Surface(rqsb.BaseSurface):
             return None
         return intersects[indices[0]]
 
-    def sample_z_at_xy_points(self, points, multiple_handling = 'any'):
+    def sample_z_at_xy_points(self, points, multiple_handling = 'any', patch = None):
         """Returns interpolated z values for an array of xy values.
 
         arguments:
             points (numpy float array of shape (..., 2 or 3)): xy points to sample surface at (z values ignored)
             multiple_handling (str, default 'any'): one of 'any', 'minimum', 'maximum', 'exception'
+            patch (int, optional): patch index; if None, results are for the full surface
 
         returns:
             numpy float array of shape points.shape[:-1] being z values interpolated from the surface z values
 
         notes:
             points must be in the same crs as the surface;
-            NaN will be set for any points that do not intersect with the surface in the xy projection;
-            multiple_handling argument controls behaviour when one sample point intersects surface more than
-            once: 'any' a random one of the intersection z values is returned; 'minimum' or 'maximum': the
+            NaN will be set for any points that do not intersect with the patch or surface in the xy projection;
+            multiple_handling argument controls behaviour when one sample point intersects more than once:
+            'any' a random one of the intersection z values is returned; 'minimum' or 'maximum': the
             numerical min or max of the z values is returned; 'exception': a ValueError is raised
         """
 
@@ -830,10 +1039,10 @@ class Surface(rqsb.BaseSurface):
         else:
             sample_xy = np.zeros((points.size // 2, 3), dtype = float)
             sample_xy[:, :2] = points.reshape((-1, 2))
-        t, p = self.triangles_and_points()
+        t, p = self.triangles_and_points(patch = patch)
         p_list = vec.points_in_triangles_njit(sample_xy, p[t], 1)
         vertical = np.array((0.0, 0.0, 1.0), dtype = float)
-        z = np.full(sample_xy.shape[0], np.NaN, dtype = float)
+        z = np.full(sample_xy.shape[0], np.nan, dtype = float)
         for triangle_index, p_index, _ in p_list:
             # todo: replace following with cheaper trilinear interpolation, given vertical intersection line
             xyz = meet.line_triangle_intersect_numba(sample_xy[p_index], vertical, p[t[triangle_index]], t_tol = 0.05)
@@ -849,17 +1058,18 @@ class Surface(rqsb.BaseSurface):
                 raise ValueError(f'multiple {self.title} surface intersections at xy: {sample_xy[p_index]}')
         return z.reshape(points.shape[:-1])
 
-    def normal_vectors(self, add_as_property: bool = False) -> np.ndarray:
-        """Returns the normal vectors for each triangle in the surface.
-        
+    def normal_vectors(self, add_as_property: bool = False, patch = None) -> np.ndarray:
+        """Returns the normal vectors for each triangle in the patch or surface.
+
         arguments:
-            add_as_property (bool): if True, face_surface_normal_vectors_array is added as a property to the model.
+            add_as_property (bool): if True, face_surface_normal_vectors_array is added as a property to the model
+            patch (int, optional): patch index; if None, normal vectors for triangles in all patches are returned
 
         returns:
-            normal_vectors_array (np.ndarray): the normal vectors corresponding to each triangle in the surface.
+            normal_vectors_array (np.ndarray): the normal vectors corresponding to each triangle in the surface
         """
         crs = rqc.Crs(self.model, uuid = self.crs_uuid)
-        triangles, points = self.triangles_and_points()
+        triangles, points = self.triangles_and_points(patch = patch)
         if crs.xy_units != crs.z_units:
             points = points.copy()
             wam.convert_lengths(points[:, 2], crs.z_units, crs.xy_units)
@@ -918,6 +1128,47 @@ class Surface(rqsb.BaseSurface):
 
         return ep
 
+    def resampled_surface(self, title = None):
+        """Creates a new surface which is a refined version of this surface; each triangle is divided equally into 4 new triangles.
+
+        arguments:
+            title (str): title for the output triangulated set, if None the title will be inherited from the input surface
+
+        returns:
+            resqpy.surface.Surface object, with extra_metadata ('resampled from surface': uuid), where uuid is for the original surface uuid
+        """
+        rt, rp = self.triangles_and_points()
+        edge1 = np.mean(rp[rt[:]][:, ::2, :], axis = 1)
+        edge2 = np.mean(rp[rt[:]][:, 1:, :], axis = 1)
+        edge3 = np.mean(rp[rt[:]][:, :2, :], axis = 1)
+        allpoints = np.concatenate((rp, edge1, edge2, edge3), axis = 0)
+        count1 = len(rp)
+        count2 = count1 + len(edge1)
+        count3 = count2 + len(edge2)
+        tris = []
+        for i in range(len(rt)):
+            tris.extend([[rt[i][0], count1 + i, count3 + i], [rt[i][1], count2 + i, count3 + i],
+                         [rt[i][2], count1 + i, count2 + i], [count1 + i, count2 + i, count3 + i]])
+
+        # TODO: implement alternate solution using edge functions in olio triangulation to optimise
+        points_unique, inverse = np.unique(allpoints, axis = 0, return_inverse = True)
+        t_type = np.int32 if len(allpoints) <= 2_147_483_647 else np.int64
+        tris = np.array(tris, dtype = t_type)
+        tris_unique = np.empty(shape = tris.shape, dtype = t_type)
+        tris_unique[:, 0] = inverse[tris[:, 0]]
+        tris_unique[:, 1] = inverse[tris[:, 1]]
+        tris_unique[:, 2] = inverse[tris[:, 2]]
+
+        if title is None:
+            title = self.citation_title
+        resampled = rqs.Surface(self.model,
+                                title = title,
+                                crs_uuid = self.crs_uuid,
+                                extra_metadata = {'resampled from surface': str(self.uuid)})
+        resampled.set_from_triangles_and_points(tris_unique, points_unique)
+
+        return resampled
+
     def write_hdf5(self, file_name = None, mode = 'a'):
         """Create or append to an hdf5 file, writing datasets for the triangulated patches after caching arrays.
 
@@ -967,7 +1218,12 @@ class Surface(rqsb.BaseSurface):
         if not self.title:
             self.title = 'surface'
 
-        tri_rep = super().create_xml(add_as_part = False, title = title, originator = originator)
+        em = None
+        if self.normal_vector is not None:
+            assert len(self.normal_vector) == 3
+            em = {'normal vector': f'{self.normal_vector[0]},{self.normal_vector[1]},{self.normal_vector[2]}'}
+
+        tri_rep = super().create_xml(add_as_part = False, title = title, originator = originator, extra_metadata = em)
 
         # todo: if crs_uuid is None, attempt to set to surface patch crs uuid (within patch loop, below)
         if crs_uuid is not None:
@@ -1073,6 +1329,16 @@ class Surface(rqsb.BaseSurface):
 
         return tri_rep
 
+    def _load_normal_vector_from_extra_metadata(self):
+        if self.normal_vector is None and self.extra_metadata is not None:
+            nv_str = self.extra_metadata.get('normal vector')
+            if nv_str is not None:
+                nv_words = nv_str.split(',')
+                assert len(nv_words) == 3, f'failed to convert normal vector string into triplet: {nv_str}'
+                self.normal_vector = np.empty(3, dtype = float)
+                for i in range(3):
+                    self.normal_vector[i] = float(nv_words[i])
+
 
 def distill_triangle_points(t, p):
     """Returns a (triangles, points) pair with points distilled as only those used from p."""
@@ -1081,7 +1347,8 @@ def distill_triangle_points(t, p):
     # find unique points used by triangles
     p_keep = np.unique(t)
     # note new point index for each old point that is being kept
-    p_map = np.full(len(p), -1, dtype = int)
+    t_type = np.int32 if len(p) <= 2_147_483_647 else np.int64
+    p_map = np.full(len(p), -1, dtype = t_type)
     p_map[p_keep] = np.arange(len(p_keep))
     # copy those unique points into a trimmed points array
     points_distilled = p[p_keep]
@@ -1094,6 +1361,29 @@ def distill_triangle_points(t, p):
     return triangles_mapped, points_distilled
 
 
+def nan_removed_triangles_and_points(t, p):
+    """Returns a (triangles, points) pair which excludes any point involving a NaN and related triangles."""
+    assert p.ndim == 2 and p.shape[1] == 3
+    assert t.ndim == 2 and t.shape[1] == 3
+    p_nan_mask = np.any(np.isnan(p), axis = 1)
+    p_non_nan_mask = np.logical_not(p_nan_mask)
+    expanded_mask = np.empty(p.shape, dtype = bool)
+    expanded_mask[:] = np.expand_dims(p_non_nan_mask, axis = -1)
+    p_filtered = p[expanded_mask].reshape((-1, 3))
+    t_nan_mask = np.any(p_nan_mask[t], axis = 1)
+    expanded_mask = np.empty(t.shape, dtype = bool)
+    expanded_mask[:] = np.expand_dims(np.logical_not(t_nan_mask), axis = -1)
+    t_filtered = t[expanded_mask].reshape((-1, 3))
+    # modified the filtered t values to adjust for the compression of filtered p
+    t_type = np.int32 if len(p) <= 2_147_483_647 else np.int64
+    p_map = np.full(len(p), -1, dtype = t_type)
+    p_map[p_non_nan_mask] = np.arange(len(p_filtered), dtype = t_type)
+    t_filtered = p_map[t_filtered]
+    assert t_filtered.ndim == 2 and t_filtered.shape[1] == 3
+    assert not np.any(t_filtered < 0) and not np.any(t_filtered >= len(p_filtered))
+    return (t_filtered, p_filtered)
+
+
 def _adjust_flange_z(model, crs_uuid, p_xy_e, flange_start_index, t, flange_array, saucer_parameter):
     """Adjust the flange point z values (in recumbent space) by extrapolation of pair of points on original."""
 
