@@ -7,8 +7,10 @@ log = logging.getLogger(__name__)
 import math as maths
 import numpy as np
 
+import resqpy.crs as rqc
 import resqpy.surface as rqs
 import resqpy.olio.vector_utilities as vec
+import resqpy.olio.uuid as bu
 
 root_3 = maths.sqrt(3.0)
 root_3_by_2 = root_3 / 2.0
@@ -58,6 +60,10 @@ class TriMesh(rqs.Mesh):
 
         returns:
            the newly created TriMesh object
+
+        note:
+           using the z_uom argument will result in the tri mesh's full_array_ref() method returning data with
+           x and y values in the object's crs, whilst z values will be in the given uom
         """
 
         if uuid is None:
@@ -73,8 +79,15 @@ class TriMesh(rqs.Mesh):
             xyz *= t_side
             if z_values is not None:
                 xyz[:, :, 2] = z_values
+            o_a = None
             if origin is not None:
-                xyz += np.expand_dims(np.expand_dims(origin, axis = 0), axis = 0)
+                o_a = np.array(origin, dtype = float)
+                assert o_a.shape == (3,)
+                if np.isnan(o_a[2]):
+                    o_a[2] = 0.0
+                assert not np.any(np.isnan(o_a))
+                xyz += np.expand_dims(np.expand_dims(o_a, axis = 0), axis = 0)
+                o_a[2] = 0.0  # origin z included in explicit values and moved to zero
             super().__init__(parent_model,
                              mesh_flavour = 'explicit',
                              xyz_values = xyz,
@@ -86,10 +99,7 @@ class TriMesh(rqs.Mesh):
                              originator = originator,
                              extra_metadata = extra_metadata)
             self.t_side = t_side
-            self.origin = None
-            if origin is not None:
-                self.origin = np.array(origin, dtype = float)
-                assert self.origin.shape == (3,)
+            self.origin = o_a
             self.z_uom = z_uom
             self.extra_metadata['t side'] = str(t_side)
             if z_uom:
@@ -104,14 +114,22 @@ class TriMesh(rqs.Mesh):
             assert t_side is not None, 'triangle side length missing in TriMesh extra metadata'
             self.t_side = float(t_side)
             self.z_uom = self.extra_metadata.get('z uom')
-            origin = self.full_array_ref()[0, 0]
+            origin = np.zeros(3, dtype = float)
+            origin[:2] = self.full_array_ref()[0, 0, :2]
             if np.all(np.isclose(origin, 0.0)):
                 self.origin = None
             else:
                 self.origin = origin
+        self.t_type = np.int32 if self.is_big() else np.int64
 
     @classmethod
-    def from_tri_mesh_and_z_values(cls, tri_mesh, z_values, z_uom = None, title = None, surface_role = 'map'):
+    def from_tri_mesh_and_z_values(cls,
+                                   tri_mesh,
+                                   z_values,
+                                   z_uom = None,
+                                   title = None,
+                                   surface_role = 'map',
+                                   extra_metadata = None):
         """Create a new tri mesh with the same xy pattern as an existing one, updating z."""
         assert z_values.shape == (tri_mesh.nj, tri_mesh.ni)
         if not z_uom:
@@ -128,7 +146,8 @@ class TriMesh(rqs.Mesh):
                  z_uom = z_uom,
                  surface_role = surface_role,
                  crs_uuid = tri_mesh.crs_uuid,
-                 title = title)
+                 title = title,
+                 extra_metadata = extra_metadata)
         return tm
 
     def tji_for_xy(self, xy):
@@ -200,17 +219,20 @@ class TriMesh(rqs.Mesh):
             base edge towards point 2; f1 is component towards point 1; f0 is component towards point 0;
             the trilinear coordinates sum to one and can be used as weights to interpolate z values at points
         """
-        x = xy_array[..., 0]
-        y = xy_array[..., 1]
+        x = xy_array[..., 0].copy()
+        y = xy_array[..., 1].copy()
         if self.origin is not None:
             x -= self.origin[0]
             y -= self.origin[1]
+        mask = np.logical_or(np.isnan(x), np.isnan(y))
+        x[mask] = 0.0
+        y[mask] = 0.0
         jp = y / (self.t_side * root_3_by_2)
-        j = np.floor(jp)
-        mask = np.logical_or(j < 0, j >= self.nj - 1)
+        j = np.floor(jp).astype(int)
+        mask = np.logical_or(mask, np.logical_or(j < 0, j >= self.nj - 1))
         fy = np.where(j % 2, (j + 1).astype(float) - jp, jp - j.astype(float))
         ip = x / self.t_side - 0.5 * fy
-        i = np.floor(ip)
+        i = np.floor(ip).astype(int)
         mask = np.logical_or(mask, np.logical_or(i < 0, i >= self.ni - 1))
         fx = ip - i.astype(float)
         i *= 2
@@ -220,8 +242,8 @@ class TriMesh(rqs.Mesh):
         fy[am] = 1.0 - fy[am]
         j[mask] = -1
         i[mask] = -1
-        fx[mask] = np.NaN
-        fy[mask] = np.NaN
+        fx[mask] = np.nan
+        fy[mask] = np.nan
 
         return (np.stack((j, i), axis = -1), np.stack((1.0 - (fx + fy), fx, fy), axis = -1))
 
@@ -281,7 +303,7 @@ class TriMesh(rqs.Mesh):
     def tri_nodes_for_tji(self, tji):
         """Return mesh node indices, shape (3, 2), for triangle tji (tj, ti)."""
         j, i = tji
-        tn = np.zeros((3, 2), dtype = int)
+        tn = np.zeros((3, 2), dtype = self.t_type)
         j_odd = j % 2
         i2, i_odd = divmod(i, 2)
         assert 0 <= j < self.nj - 1 and 0 <= i < 2 * (self.ni - 1)
@@ -304,7 +326,7 @@ class TriMesh(rqs.Mesh):
         j = tji_array[..., 0]
         i = tji_array[..., 1]
         tn_shape = tuple(list(tji_array.shape[:-1]) + [3, 2])
-        tn = np.zeros(tn_shape, dtype = int)
+        tn = np.zeros(tn_shape, dtype = self.t_type)
         j_odd = j % 2
         i2, i_odd = np.divmod(i, 2)
         mask = np.logical_or(np.logical_or(j < 0, j >= self.nj - 1), np.logical_or(i < 0, i >= 2 * (self.ni - 1)))
@@ -321,9 +343,9 @@ class TriMesh(rqs.Mesh):
 
     def all_tri_nodes(self):
         """Returns array of mesh node indices for all triangles, shape (nj - 1, 2 * (ni - 1), 3, 2)."""
-        tna = np.zeros((self.nj - 1, 2 * (self.ni - 1), 3, 2), dtype = int)
+        tna = np.zeros((self.nj - 1, 2 * (self.ni - 1), 3, 2), dtype = self.t_type)
         # set mesh j indices
-        tna[:, :, 0, 0] = np.expand_dims(np.arange(self.nj - 1, dtype = int), axis = -1)
+        tna[:, :, 0, 0] = np.expand_dims(np.arange(self.nj - 1, dtype = self.t_type), axis = -1)
         tna[1::2, ::2, 0, 0] += 1
         tna[::2, 1::2, 0, 0] += 1
         tna[:, :, 1, 0] = tna[:, :, 0, 0]
@@ -331,7 +353,7 @@ class TriMesh(rqs.Mesh):
         tna[1::2, ::2, 2, 0] -= 2
         tna[::2, 1::2, 2, 0] -= 2
         # set mesh i indices
-        tna[:, ::2, 0, 1] = np.expand_dims(np.arange(self.ni - 1, dtype = int), axis = 0)
+        tna[:, ::2, 0, 1] = np.expand_dims(np.arange(self.ni - 1, dtype = self.t_type), axis = 0)
         tna[:, 1::2, 0, 1] = tna[:, ::2, 0, 1]
         tna[:, :, 1, 1] = tna[:, :, 0, 1] + 1
         tna[:, :, 2, 1] = tna[:, :, 0, 1]
@@ -341,7 +363,7 @@ class TriMesh(rqs.Mesh):
     def triangles_and_points(self):
         """Returns node indices and xyz points in form suitable for a Surface (triangulated set)."""
         tna = self.all_tri_nodes()
-        composite_ji = tna[:, :, :, 0] * self.ni + tna[:, :, :, 1]
+        composite_ji = (tna[:, :, :, 0] * self.ni + tna[:, :, :, 1]).astype(self.t_type)
         return (composite_ji.reshape((-1, 3)), self.full_array_ref().reshape((-1, 3)))
 
     def tji_for_triangle_index(self, ti):
@@ -389,7 +411,7 @@ class TriMesh(rqs.Mesh):
                                                          tp)
         tn_a[:, 1] *= 2  # node j
 
-        return np.concatenate((tn_a, tn_b), axis = 0)
+        return np.concatenate((tn_a, tn_b), axis = 0).astype(self.t_type)
 
     def edge_zero_crossings(self, z_values = None):
         """Returns numpy list of points from edges where z values cross zero (or given value).
@@ -543,3 +565,31 @@ class TriMesh(rqs.Mesh):
                 p = np.concatenate((p, w[crossing]))
 
         return p
+
+    def is_compatible_with(self, other_tri_mesh):
+        """Returns True if this tri mesh has the same xy points as the other."""
+
+        if other_tri_mesh is self:
+            return True
+        if other_tri_mesh is None or not isinstance(other_tri_mesh, TriMesh):
+            return False
+        if other_tri_mesh.nj != self.nj or other_tri_mesh.ni != self.ni:
+            return False
+        if not maths.isclose(other_tri_mesh.t_side, self.t_side):
+            return False
+        if (other_tri_mesh.origin is None and self.origin is not None):
+            if not (maths.isclose(self.origin[0], 0.0) and maths.isclose(self.origin[1], 0.0)):
+                return False
+        elif (other_tri_mesh.origin is not None and self.origin is None):
+            if not (maths.isclose(other_tri_mesh.origin[0], 0.0) and maths.isclose(other_tri_mesh.origin[1], 0.0)):
+                return False
+        elif self.origin is not None and not (maths.isclose(other_tri_mesh.origin[0], self.origin[0]) and
+                                              maths.isclose(other_tri_mesh.origin[1], self.origin[1])):
+            return False
+        if not bu.matching_uuids(self.crs_uuid, other_tri_mesh.crs_uuid):
+            crs = rqc.Crs(self.model, uuid = self.crs_uuid)
+            other_crs = rqc.Crs(other_tri_mesh.model, uuid = other_tri_mesh.crs_uuid)
+            if other_crs != crs:
+                return False
+
+        return True
