@@ -335,7 +335,7 @@ class VerticalPrismGrid(PrismGrid):
             if surf == 0:
                 # allow NaN entries to handle unused distant circumcentres in Voronoi graph data
                 # assert not np.any(nan_lines), 'top surface does not cover all column points'
-                single_intersects[nan_lines] = np.NaN
+                single_intersects[nan_lines] = np.nan
             else:
                 single_intersects[nan_lines] = points[surf - 1][nan_lines]
             # populate z values for layer of points
@@ -624,7 +624,7 @@ class VerticalPrismGrid(PrismGrid):
             ppc = rqp.selective_version_of_collection(pc,
                                                       continuous = True,
                                                       realization = realization,
-                                                      property_kind = 'permeability rock')
+                                                      property_kind = 'rock permeability')
             assert ppc.number_of_parts() > 0, 'no permeability properties available for vertical prism grid'
 
             # look for a triple permeability; if present, assume to be per face horizontal permeabilities
