@@ -14,6 +14,7 @@ import numpy as np
 import pandas as pd
 from functools import partial
 
+import resqpy.crs as rqc
 import resqpy.lines as rql
 import resqpy.olio.uuid as bu
 import resqpy.olio.vector_utilities as vec
@@ -21,7 +22,7 @@ import resqpy.olio.wellspec_keywords as wsk
 import resqpy.olio.write_hdf5 as rwh5
 import resqpy.olio.xml_et as rqet
 import resqpy.organize as rqo
-import resqpy.weights_and_measures as bwam
+import resqpy.weights_and_measures as wam
 import resqpy.well
 import resqpy.well._md_datum as rqmdd
 import resqpy.well._wellbore_frame as rqwbf
@@ -62,7 +63,9 @@ class Trajectory(BaseResqpy):
                  set_tangent_vectors = False,
                  hdf5_source_model = None,
                  originator = None,
-                 extra_metadata = None):
+                 extra_metadata = None,
+                 mds = None,
+                 control_points = None):
         """Creates a new trajectory object and optionally loads it from xml, deviation survey, pandas dataframe, or
 
         ascii file.
@@ -105,6 +108,10 @@ class Trajectory(BaseResqpy):
               ignored if uuid is not None
            extra_metadata (dict, optional): string key, value pairs to add as extra metadata for the trajectory;
               ignored if uuid is not None
+           mds (1D numpy float array, optional): mwasured depths; can be used alongside control_points as an
+              alternative to data_frame
+           control_points (2D numpy float array of shape (N, 3)): control points; can be used alongside mds as
+              an alternative to data_frame
 
         returns:
            the newly created wellbore trajectory object
@@ -162,6 +169,13 @@ class Trajectory(BaseResqpy):
         # Using dictionary mapping to replicate a switch statement. The init_function key is chosen based on the
         # data source and the correct function is then called based on the init_function_dict
         init_function_dict = {
+            'control_points':
+                partial(self.load_from_mds_and_control_points,
+                        mds,
+                        control_points,
+                        md_uom = length_uom,
+                        md_datum = md_datum,
+                        set_tangent_vectors = set_tangent_vectors),
             'deviation_survey':
                 partial(self.compute_from_deviation_survey,
                         method = 'minimum curvature',
@@ -189,12 +203,14 @@ class Trajectory(BaseResqpy):
         chosen_init_method = self.__choose_init_method(data_frame = data_frame,
                                                        cell_kji0_list = cell_kji0_list,
                                                        wellspec_file = wellspec_file,
-                                                       deviation_survey_file = ascii_trajectory_file)
+                                                       deviation_survey_file = ascii_trajectory_file,
+                                                       mds = mds,
+                                                       control_points = control_points)
 
         try:
             init_function_dict[chosen_init_method]()
         except KeyError:
-            log.warning('invalid combination of input arguments specified')
+            log.error('invalid combination of input arguments specified')
 
         # todo: create from already loaded deviation_survey node (ie. derive xyz points)
 
@@ -214,11 +230,12 @@ class Trajectory(BaseResqpy):
             if self.knot_count > 1:
                 self.set_tangents()
 
-    def __choose_init_method(self, data_frame, cell_kji0_list, wellspec_file, deviation_survey_file):
+    def __choose_init_method(self, data_frame, cell_kji0_list, wellspec_file, deviation_survey_file, mds,
+                             control_points):
         """Choose an init method based on data source."""
 
-        if self.deviation_survey is not None:
-            return 'deviation_survey'
+        if mds is not None and control_points is not None:
+            return 'control_points'
         elif data_frame is not None:
             return 'data_frame'
         elif cell_kji0_list is not None:
@@ -227,6 +244,8 @@ class Trajectory(BaseResqpy):
             return 'wellspec_file'
         elif deviation_survey_file:
             return 'ascii_trajectory_file'
+        elif self.deviation_survey is not None:
+            return 'deviation_survey'
         else:
             return None
 
@@ -366,8 +385,7 @@ class Trajectory(BaseResqpy):
             self.knot_count = len(data_frame)
             assert self.knot_count >= 2  # vertical well could be hamdled by allowing a single station in survey?
             self.line_kind_index = 5  # assume minimum curvature spline
-            #         self.md_uom = bwam.p_length_unit(md_uom)
-            self.md_uom = bwam.rq_length_unit(md_uom)
+            self.md_uom = wam.rq_length_unit(md_uom)
             start = data_frame.iloc[0]
             finish = data_frame.iloc[-1]
             if title:
@@ -388,12 +406,49 @@ class Trajectory(BaseResqpy):
             self.md_datum = md_datum
         except Exception:
             log.exception('failed to load trajectory object from data frame')
+            raise
+
+    def load_from_mds_and_control_points(
+            self,
+            mds,
+            control_points,
+            md_uom = 'm',
+            md_domain = None,
+            md_datum = None,  # MdDatum object
+            title = None,
+            set_tangent_vectors = True):
+        """Load MD and control points (xyz) data directly from numpy arrays."""
+
+        if isinstance(mds, list) or isinstance(mds, tuple):
+            mds = np.array(mds, dtype = float)
+        assert mds.ndim == 1
+        self.knot_count = len(mds)
+        assert self.knot_count >= 2  # vertical well could be hamdled by allowing a single station in survey?
+        if isinstance(control_points, list) or isinstance(control_points, tuple):
+            control_points = np.array(control_points, dtype = float)
+        assert control_points.shape == (self.knot_count, 3)
+        self.line_kind_index = 5  # assume minimum curvature spline
+        self.md_uom = wam.rq_length_unit(md_uom)
+        if title:
+            self.title = title
+        self.start_md = mds[0]
+        self.finish_md = mds[-1]
+        if md_domain is not None:
+            self.md_domain = md_domain
+        self.measured_depths = np.empty(self.knot_count, dtype = float)
+        self.measured_depths[:] = mds
+        self.control_points = np.empty((self.knot_count, 3), dtype = float)
+        self.control_points[:] = control_points
+        self.tangent_vectors = None
+        if set_tangent_vectors:
+            self.set_tangents()
+        self.md_datum = md_datum
 
     def load_from_cell_list(self, grid, cell_kji0_list, spline_mode = 'cube', md_uom = 'm'):
         """Loads the trajectory object based on the centre points of a list of cells."""
 
         assert grid is not None, 'grid argument missing for trajectory initislisation from cell list'
-        cell_kji0_list = np.array(cell_kji0_list, dtype = int)
+        cell_kji0_list = np.array(cell_kji0_list, dtype = np.int32)
         assert cell_kji0_list.ndim == 2 and cell_kji0_list.shape[1] == 3
         assert spline_mode in ['none', 'linear', 'square', 'cube']
 
@@ -401,7 +456,7 @@ class Trajectory(BaseResqpy):
 
         knot_count = len(cell_kji0_list) + 2
         self.line_kind_index = 5  # 5 means minimum curvature spline; todo: set to cubic spline value?
-        self.md_uom = bwam.rq_length_unit(md_uom)
+        self.md_uom = wam.rq_length_unit(md_uom)
         self.start_md = 0.0
         points = np.empty((knot_count, 3))
         points[1:-1] = cell_centres
@@ -428,7 +483,7 @@ class Trajectory(BaseResqpy):
         df = wellspec_dict[well_name]
         assert len(df) > 0, 'no rows of perforation data found in wellspec for well ' + well_name
 
-        cell_kji0_list = np.empty((len(df), 3), dtype = int)
+        cell_kji0_list = np.empty((len(df), 3), dtype = np.int32)
         cell_kji0_list[:, 0] = df['L']
         cell_kji0_list[:, 1] = df['JW']
         cell_kji0_list[:, 2] = df['IW']
@@ -582,9 +637,7 @@ class Trajectory(BaseResqpy):
         df.to_csv(trajectory_file, sep = sep, index = False, mode = mode)
 
     def xyz_for_md(self, md):
-        """Returns an xyz triplet corresponding to the given measured depth; uses simple linear interpolation between
-
-        knots.
+        """Returns xyz corresponding to the given measured depth; uses simple linear interpolation between knots.
 
         args:
            md (float): measured depth for which xyz location is required; units must be those of self.md_uom
@@ -623,13 +676,37 @@ class Trajectory(BaseResqpy):
             return interpolate(np.array(self.md_datum.location), self.control_points[0], md / self.start_md)
         return search(md, 0, self.knot_count - 1)
 
+    def inclinations(self):
+        """Returns a numpy array of inclinations in degrees, zero being vertical, with a value per interval.
+
+        note:
+           this method returns inclinations of piecewise linear line segments between control points;
+           calling code can alternatively use the tangent vectors at knots to derive similar information
+        """
+        assert self.knot_count >= 2 and self.control_points.shape == (self.knot_count, 3)
+        crs = rqc.Crs(self.model, uuid = self.crs_uuid)
+        interval_vectors = self.control_points[1:] - self.control_points[:-1]
+        if crs.xy_units != crs.z_units:
+            wam.convert_lengths(interval_vectors[:, 2], crs.z_units, crs.xy_units)
+        if not crs.z_inc_down:
+            interval_vectors[:, 2] = -interval_vectors[:, 2]
+        interval_h = np.sqrt((interval_vectors[:, 0] * interval_vectors[:, 0]) +
+                             (interval_vectors[:, 1] * interval_vectors[:, 1]))
+        restore = np.seterr(all = 'ignore')
+        incl_radians = np.arctan(interval_h / interval_vectors[:, 2])  # horizontal / vertical
+        np.seterr(**restore)
+        incl_radians = np.where(interval_vectors[:, 2] == 0.0, maths.pi / 2.0, incl_radians)
+        incl_radians = np.where(incl_radians < 0.0, incl_radians + maths.pi, incl_radians)
+        return np.degrees(incl_radians)
+
     def splined_trajectory(self,
                            well_name,
                            min_subdivisions = 1,
                            max_segment_length = None,
                            max_degrees_per_knot = 5.0,
                            use_tangents_if_present = True,
-                           store_tangents_if_calculated = True):
+                           store_tangents_if_calculated = True,
+                           inherit_interpretation = True):
         """Creates and returns a new Trajectory derived as a cubic spline of this trajectory.
 
         arguments:
@@ -697,6 +774,10 @@ class Trajectory(BaseResqpy):
 
         spline_traj.set_measured_depths()
 
+        if inherit_interpretation:
+            spline_traj.wellbore_interpretation = self.wellbore_interpretation
+            spline_traj.wellbore_feature = self.wellbore_feature
+
         return spline_traj
 
     def set_measured_depths(self):
@@ -840,7 +921,7 @@ class Trajectory(BaseResqpy):
 
         md_uom = rqet.SubElement(wbt_node, ns['resqml2'] + 'MdUom')
         md_uom.set(ns['xsi'] + 'type', ns['eml'] + 'LengthUom')
-        md_uom.text = bwam.rq_length_unit(self.md_uom)
+        md_uom.text = wam.rq_length_unit(self.md_uom)
 
         if self.md_domain:
             domain_node = rqet.SubElement(wbt_node, ns['resqml2'] + 'MdDomain')
@@ -912,7 +993,7 @@ class Trajectory(BaseResqpy):
         """
 
         if self.deviation_survey is not None:
-            ds_root = self.deviation_survey.root_node
+            ds_root = self.deviation_survey.root
             self.model.create_ref_node('DeviationSurvey',
                                        rqet.find_tag(rqet.find_tag(ds_root, 'Citation'), 'Title').text,
                                        bu.uuid_from_string(ds_root.attrib['uuid']),
@@ -949,8 +1030,8 @@ class Trajectory(BaseResqpy):
                 self.model.create_reciprocal_relationship(wbt_node, 'destinationObject', self.md_datum.root,
                                                           'sourceObject')
                 if self.deviation_survey is not None:
-                    self.model.create_reciprocal_relationship(wbt_node, 'destinationObject',
-                                                              self.deviation_survey.root_node, 'sourceObject')
+                    self.model.create_reciprocal_relationship(wbt_node, 'destinationObject', self.deviation_survey.root,
+                                                              'sourceObject')
                 if interp_root is not None:
                     self.model.create_reciprocal_relationship(wbt_node, 'destinationObject', interp_root,
                                                               'sourceObject')
