@@ -1,6 +1,4 @@
-"""_wellbore_frame.py: resqpy well module providing wellbore frame class"""
-
-import resqpy.well
+"""WellboreFrame class."""
 
 # Nexus is a registered trademark of the Halliburton Company
 # RMS and ROXAR are registered trademarks of Roxar Software Solutions AS, an Emerson company
@@ -16,11 +14,11 @@ import resqpy.olio.write_hdf5 as rwh5
 import resqpy.olio.xml_et as rqet
 import resqpy.organize as rqo
 import resqpy.property as rqp
+import resqpy.well as rqw
+import resqpy.well.well_utils as rqwu
 from resqpy.olio.base import BaseResqpy
 from resqpy.olio.xml_namespaces import curly_namespace as ns
 
-from .well_utils import load_hdf5_array
-
 
 class WellboreFrame(BaseResqpy):
     """Class for RESQML WellboreFrameRepresentation objects (supporting well log Properties)
@@ -56,7 +54,7 @@ class WellboreFrame(BaseResqpy):
            trajectory (Trajectory object, optional): the trajectory of the well; required if loading from
               list of measured depths
            mds (optional numpy 1D array, tuple or list of floats): ordered list of measured depths which
-              will constitute the frame; ignored if uuid is not None
+              will constitute the frame; ignored if uuid is not None; units are those of trajectory mds
            represented_interp (wellbore interpretation object, optional): if present, is noted as the wellbore
               interpretation object which this frame relates to; ignored if uuid is not None
            title (str, optional): the citation title to use for a new wellbore frame;
@@ -71,13 +69,15 @@ class WellboreFrame(BaseResqpy):
 
         note:
            if initialising from a list of measured depths, the wellbore trajectory object must already exist
+
+        :meta common:
         """
 
-        #: Associated wellbore trajectory, an instance of :class:`resqpy.well.Trajectory`.
+        #: associated wellbore trajectory, an instance of :class:`resqpy.well.Trajectory`.
         self.trajectory = trajectory
         self.trajectory_uuid = None if trajectory is None else trajectory.uuid
 
-        #: Instance of :class:`resqpy.organize.WellboreInterpretation`
+        #: instance of :class:`resqpy.organize.WellboreInterpretation`
         self.wellbore_interpretation = represented_interp
         self.wellbore_feature = None
         self.feature_and_interpretation_to_be_written = False
@@ -88,7 +88,9 @@ class WellboreFrame(BaseResqpy):
         #: node_count measured depths (in same units and datum as trajectory) of cell entry and/or exit points
         self.node_mds = None
 
-        #: All logs associated with the wellbore frame; an instance of :class:`resqpy.property.WellLogCollection`
+        #: all properties, including indexable of nodes or intervals; an instance of :class:`resqpy.property.PropertyCollection`
+        self.property_collection = None
+        #: all logs associated with the wellbore frame; an instance of :class:`resqpy.property.WellLogCollection`
         self.logs = None
 
         super().__init__(model = parent_model,
@@ -97,15 +99,12 @@ class WellboreFrame(BaseResqpy):
                          originator = originator,
                          extra_metadata = extra_metadata)
 
-        if self.root is None and trajectory is not None and mds is not None and len(mds) > 1:
+        if self.root is None and trajectory is not None and mds is not None:
+            assert len(mds) > 1, 'at least two measured depth nodes needed for wellbore frame'
             self.node_count = len(mds)
             self.node_mds = np.array(mds)
             assert self.node_mds is not None and self.node_mds.ndim == 1
 
-        # UUID needs to have been created before LogCollection can be made
-        # TODO: Figure out when this should be created, and how it is kept in sync when new logs are created
-        self.logs = rqp.WellLogCollection(frame = self)
-
     def _load_from_xml(self):
         """Loads the wellbore frame object from an xml node (and associated hdf5 data)."""
 
@@ -117,7 +116,7 @@ class WellboreFrame(BaseResqpy):
         trajectory_uuid = bu.uuid_from_string(rqet.find_nested_tags_text(node, ['Trajectory', 'UUID']))
         assert trajectory_uuid is not None, 'wellbore frame trajectory reference not found in xml'
         if self.trajectory is None:
-            self.trajectory = resqpy.well.Trajectory(self.model, uuid = trajectory_uuid)
+            self.trajectory = rqw.Trajectory(self.model, uuid = trajectory_uuid)
         else:
             assert bu.matching_uuids(self.trajectory.uuid, trajectory_uuid), 'wellbore frame trajectory uuid mismatch'
 
@@ -127,7 +126,7 @@ class WellboreFrame(BaseResqpy):
 
         mds_node = rqet.find_tag(node, 'NodeMd')
         assert mds_node is not None, 'wellbore frame measured depths hdf5 reference not found in xml'
-        load_hdf5_array(self, mds_node, 'node_mds')
+        rqwu.load_hdf5_array(self, mds_node, 'node_mds')
 
         assert self.node_mds is not None and self.node_mds.ndim == 1 and self.node_mds.size == self.node_count
 
@@ -137,9 +136,8 @@ class WellboreFrame(BaseResqpy):
         else:
             self.wellbore_interpretation = rqo.WellboreInterpretation(self.model, uuid = interp_uuid)
 
-        # Create well log collection of all log data
+        self.extract_property_collection()
         self.logs = rqp.WellLogCollection(frame = self)
-        # pass
 
     def extract_crs_uuid(self):
         """Returns the uuid of the coordinate reference system used by the related trajectory."""
@@ -148,6 +146,41 @@ class WellboreFrame(BaseResqpy):
             return None
         return self.trajectory.crs_uuid
 
+    def extract_property_collection(self):
+        """Returns property collection for the frame, creating attribute if not already established."""
+        if self.property_collection is None:
+            self.property_collection = rqp.PropertyCollection(support = self)
+        return self.property_collection
+
+    def extract_log_collection(self, refresh = False):
+        """Returns collection of well logs (nodes properties) for this frame, creating if refresh or not already established."""
+        if refresh:
+            self.logs = None
+        if self.logs is None:
+            self.logs = rqp.WellLogCollection(frame = self)
+        return self.logs
+
+    def interval_for_md(self, md):
+        """Returns wellbore frame interval index and fractional way along interval, for given md.
+
+        arguments:
+            md (float): measured depth, in units used by trajectory mds
+
+        returns:
+            (int, float) where int is the index of the wellbore frame interval containing md, and float is a fraction
+                way through that interval of md, in range 0.0 to 1.0
+
+        note:
+            if md is outside the range covered by the wellbore frame intervals, an index of -1 is returned and
+            the fraction will be 0.0 for an md shallower than the frame intervals, 1.0 for deeper
+        """
+        if md < self.node_mds[0]:
+            return -1, 0.0  # -1 indicates md is not in any frame interval, 0.0 indicates too shallow
+        for i in range(self.node_count - 1):
+            if md <= self.node_mds[i + 1]:
+                return i, (md - self.node_mds[i]) / (self.node_mds[i + 1] - self.node_mds[i])
+        return -1, 1.0  # 1.0 indicates md is deeper than the intervals covered by the frame
+
     def create_feature_and_interpretation(self):
         """Instantiate new empty WellboreFeature and WellboreInterpretation objects, if a wellboreinterpretation does
 
@@ -163,7 +196,7 @@ class WellboreFrame(BaseResqpy):
                                                                       wellbore_feature = self.wellbore_feature)
             self.feature_and_interpretation_to_be_written = True
         else:
-            log.info("WellboreInterpretation already exists")
+            log.debug("WellboreInterpretation for {self.title} already exists")
 
     def write_hdf5(self, file_name = None, mode = 'a'):
         """Create or append to an hdf5 file, writing datasets for the measured depths."""
