@@ -171,12 +171,6 @@ def well_name(well_object, model = None):
             return root_b
         if b is None or len(b) == 0:
             return root_a
-        parts_like_a = model.parts(title = a)
-        parts_like_b = model.parts(title = b)
-        if len(parts_like_a) > 1 and len(parts_like_b) == 1:
-            return root_b
-        elif len(parts_like_b) > 1 and len(parts_like_a) == 1:
-            return root_a
         a_digits = 0
         for c in a:
             if c.isdigit():
@@ -187,6 +181,12 @@ def well_name(well_object, model = None):
                 b_digits += 1
         if a_digits < b_digits:
             return root_b
+        elif b_digits < a_digits:
+            return root_a
+        parts_like_a = model.parts(title = a)
+        parts_like_b = model.parts(title = b)
+        if len(parts_like_a) > len(parts_like_b):
+            return root_b
         return root_a
 
     def best_root(model, roots_list):
@@ -442,10 +442,10 @@ def add_logs_from_cellio(blockedwell, cellio):
         df = df.apply(pd.to_numeric)
         # Get the cell_indices from the grid for the given i/j/k
         df['cell_indices'] = grid.natural_cell_indices(
-            np.array((df['k_index'] - 1, df['j_index'] - 1, df['i_index'] - 1), dtype = int).T)
+            np.array((df['k_index'] - 1, df['j_index'] - 1, df['i_index'] - 1), dtype = np.int32).T)
         df = df.drop(['i_index', 'j_index', 'k_index', 'x_in', 'y_in', 'z_in', 'x_out', 'y_out', 'z_out'], axis = 1)
-    assert (df['cell_indices'] == blockedwell.cell_indices
-           ).all(), 'Cell indices do not match between blocked well and log inputs'
+    assert (df['cell_indices'] == blockedwell.cell_indices).all(),  \
+        'Cell indices do not match between blocked well and log inputs'
 
     # Work out if the data columns are continuous, categorical or discrete
     type_dict = {}
@@ -468,11 +468,11 @@ def add_logs_from_cellio(blockedwell, cellio):
         if log not in ['cell_indices']:
             data_type = type_dict[log]
             if log == 'ZONES':
-                data_type, dtype, null, discrete = 'discrete', int, -1, True
+                data_type, dtype, null, discrete = 'discrete', np.int32, -1, True
             elif data_type == 'continuous':
                 dtype, null, discrete = float, np.nan, False
             else:
-                dtype, null, discrete = int, -1, True
+                dtype, null, discrete = np.int32, -1, True
             if data_type == 'categorical':
                 lookup_uuid = lookup_dict[log]  # For categorical data, find or generate a StringLookupTable
             else:
